"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CircularActivityIndicator = void 0;
var _reactNativeSvg = require("react-native-svg");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _useTheme = require("../../../theme/useTheme.hook");
var _circularActivityIndicator = require("./circular-activity-indicator.styles");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const CIRCUMFERENCE = 120;
const STROKE_WIDTH_COEFF = 0.04;
const TRANSPARENT_COLOR = 'transparent';
const DETERMINATE_ANIMATION_DURATION = 1000;
const INDETERMINATE_ANIMATION_DURATION = 800;
const AnimatedCircle = _reactNativeReanimated.default.createAnimatedComponent(_reactNativeSvg.Circle);
const CircularActivityIndicator = _ref => {
  let {
    progress,
    trackColor,
    indicatorColor,
    strokeWidth,
    size = CIRCUMFERENCE,
    determinateAnimationDuration = DETERMINATE_ANIMATION_DURATION,
    indeterminateAnimationDuration = INDETERMINATE_ANIMATION_DURATION,
    style,
    ...props
  } = _ref;
  const appliedStrokeWidth = strokeWidth ?? size * STROKE_WIDTH_COEFF;
  const radius = size / (2 * Math.PI);
  const halfCircle = radius + appliedStrokeWidth;
  const diameter = 2 * halfCircle;
  const {
    primary
  } = (0, _useTheme.useTheme)();
  const rotate = (0, _reactNativeReanimated.useSharedValue)(0);
  const indicatorProgress = (0, _reactNativeReanimated.useSharedValue)(0);
  const animatedViewStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    transform: [{
      rotate: `${rotate.value}deg`
    }]
  }), []);
  const animatedCircleProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    strokeDashoffset: size * (1 - indicatorProgress.value)
  }), []);
  (0, _react.useEffect)(() => {
    if (typeof progress === 'undefined') {
      startIndeterminateAnimation();
    }
    if (typeof progress === 'number') {
      indicatorProgress.value = (0, _reactNativeReanimated.withTiming)(progress / 100, {
        duration: determinateAnimationDuration,
        easing: _reactNativeReanimated.Easing.linear
      });
    }
  }, [progress]);
  const startIndeterminateAnimation = (0, _react.useCallback)(() => {
    indicatorProgress.value = (0, _reactNativeReanimated.withRepeat)((0, _reactNativeReanimated.withSequence)((0, _reactNativeReanimated.withTiming)(0.7, {
      duration: indeterminateAnimationDuration / 1.25
    }), (0, _reactNativeReanimated.withTiming)(0.1, {
      duration: indeterminateAnimationDuration * 2
    })), -1, true);
    rotate.value = (0, _reactNativeReanimated.withRepeat)((0, _reactNativeReanimated.withTiming)(360, {
      duration: indeterminateAnimationDuration,
      easing: _reactNativeReanimated.Easing.linear
    }), -1);
  }, []);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [_circularActivityIndicator.styles.container, style]
  }, props), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: animatedViewStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Svg, {
    width: diameter,
    height: diameter,
    viewBox: `0 0 ${diameter} ${diameter}`
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.G, {
    origin: halfCircle,
    rotation: "-90"
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Circle, {
    cx: "50%",
    cy: "50%",
    r: radius,
    stroke: trackColor ?? TRANSPARENT_COLOR,
    fill: TRANSPARENT_COLOR,
    strokeWidth: strokeWidth
  }), /*#__PURE__*/_react.default.createElement(AnimatedCircle, {
    cx: "50%",
    cy: "50%",
    r: radius,
    animatedProps: animatedCircleProps,
    strokeWidth: appliedStrokeWidth,
    stroke: indicatorColor ?? primary.background,
    fill: TRANSPARENT_COLOR,
    strokeDasharray: size
  })))));
};
exports.CircularActivityIndicator = CircularActivityIndicator;
//# sourceMappingURL=CircularActivityIndicator.component.js.map