"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LinearActivityIndicator = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _useTheme = require("../../../theme/useTheme.hook");
var _linearActivityIndicator = require("./linear-activity-indicator.styles");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const TRACK_HEIGHT = 4;
const INDICATOR_WIDTH_COEFF = 0.7;
const DETERMINATE_ANIMATION_DURATION = 1000;
const INDETERMINATE_ANIMATION_DURATION = 1500;
const LinearActivityIndicator = _ref => {
  let {
    progress,
    trackColor,
    indicatorColor,
    trackHeight = TRACK_HEIGHT,
    indicatorWidthCoeff = INDICATOR_WIDTH_COEFF,
    determinateAnimationDuration = DETERMINATE_ANIMATION_DURATION,
    indeterminateAnimationDuration = INDETERMINATE_ANIMATION_DURATION,
    style,
    ...props
  } = _ref;
  const {
    primary,
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  const position = (0, _reactNativeReanimated.useSharedValue)(0);
  const indicatorProgress = (0, _reactNativeReanimated.useSharedValue)(0);
  const indicatorAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    width: `${indicatorProgress.value * 100}%`,
    start: `${position.value * 100}%`
  }), []);
  (0, _react.useEffect)(() => {
    if (typeof progress === 'undefined') {
      startIndererminateAnimation();
    }
    if (typeof progress === 'number') {
      indicatorProgress.value = (0, _reactNativeReanimated.withTiming)(progress / 100, {
        duration: determinateAnimationDuration,
        easing: _reactNativeReanimated.Easing.linear
      });
    }
  }, [progress, determinateAnimationDuration]);
  const startIndererminateAnimation = (0, _react.useCallback)(() => {
    indicatorProgress.value = (0, _reactNativeReanimated.withRepeat)((0, _reactNativeReanimated.withDelay)(indeterminateAnimationDuration * 0.2, (0, _reactNativeReanimated.withSequence)((0, _reactNativeReanimated.withTiming)(indicatorWidthCoeff, {
      duration: indeterminateAnimationDuration * 0.4,
      easing: _reactNativeReanimated.Easing.inOut(_reactNativeReanimated.Easing.ease)
    }), (0, _reactNativeReanimated.withTiming)(0, {
      duration: indeterminateAnimationDuration * 0.4,
      easing: _reactNativeReanimated.Easing.in(_reactNativeReanimated.Easing.ease)
    }))), -1, true);
    position.value = (0, _reactNativeReanimated.withRepeat)((0, _reactNativeReanimated.withDelay)(indeterminateAnimationDuration * 0.4, (0, _reactNativeReanimated.withTiming)(1, {
      duration: indeterminateAnimationDuration * 0.6
    })), -1);
  }, [indeterminateAnimationDuration, indicatorWidthCoeff]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [_linearActivityIndicator.styles.track, {
      backgroundColor: trackColor ?? surfaceContainer.backgroundHighest,
      height: trackHeight
    }, style]
  }, props), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_linearActivityIndicator.styles.indicator, {
      backgroundColor: indicatorColor ?? primary.background
    }, indicatorAnimatedStyle]
  }));
};
exports.LinearActivityIndicator = LinearActivityIndicator;
//# sourceMappingURL=LinearActivityIndicator.component.js.map