"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ButtonSegment = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _buttonSegment = require("./button-segment.styles");
var _useTheme = require("../../../../theme/useTheme.hook");
var _convertToRgba = require("../../../../utils/convert-to-rgba");
var _useTypography = require("../../../../typography/useTypography.component");
var _AnimatedSelectedIcon = require("./animated-selected-icon/AnimatedSelectedIcon.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_ICON_SIZE = 18;
const ButtonSegment = /*#__PURE__*/_react.default.memo(_ref => {
  let {
    value,
    selected,
    disabled,
    Icon,
    label,
    multiSelectionEnabled,
    withCheckmark = true,
    onSegmentPress,
    iconSize = DEFAULT_ICON_SIZE,
    labelStyle,
    iconColor,
    rippleColor,
    style,
    ...props
  } = _ref;
  const {
    labelLarge
  } = (0, _useTypography.useTypography)();
  const {
    surface,
    secondaryContainer
  } = (0, _useTheme.useTheme)();
  const fill = (0, _reactNativeReanimated.useSharedValue)(Number(selected));
  const labelDisabledColor = (0, _react.useMemo)(() => (0, _convertToRgba.convertToRGBA)(surface.text, 0.38), []);
  const defaultIconColor = selected ? secondaryContainer.text : iconColor ?? surface.text;
  const appliedIconColor = disabled ? labelDisabledColor : defaultIconColor;
  const iconProps = {
    size: iconSize,
    color: appliedIconColor
  };
  (0, _react.useEffect)(() => {
    fill.value = (0, _reactNativeReanimated.withTiming)(Number(selected));
  }, [selected]);
  const animatedLabelStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    color: disabled ? labelDisabledColor : (0, _reactNativeReanimated.interpolateColor)(fill.value, [0, 1], [surface.text, secondaryContainer.text])
  }), [disabled]);
  const circleAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      opacity: fill.value,
      width: `${(0, _reactNativeReanimated.interpolate)(fill.value, [0, 1], [0, 100])}%`
    };
  }, []);
  const handleSegmentPress = () => {
    if (multiSelectionEnabled) {
      handleMultiplyChoosing();
    } else {
      onSegmentPress([value]);
    }
  };
  const handleMultiplyChoosing = () => {
    onSegmentPress(prevValues => {
      const filteredCurrValuesDependsOnLength = prevValues.length === 1 ? prevValues : prevValues.filter(prevValue => prevValue !== value);
      return selected ? filteredCurrValuesDependsOnLength : [...prevValues, value];
    });
  };
  const renderIconConditionally = () => Icon ? /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    layout: _reactNativeReanimated.LinearTransition,
    entering: _reactNativeReanimated.FadeIn,
    exiting: _reactNativeReanimated.FadeOut
  }, /*#__PURE__*/_react.default.createElement(Icon, iconProps)) : null;
  return /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, _extends({
    style: [_buttonSegment.styles.container, style],
    disabled: disabled
  }, props, {
    onPress: handleSegmentPress
  }), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_buttonSegment.styles.ripple, {
      backgroundColor: rippleColor ?? secondaryContainer.background
    }, circleAnimatedStyle]
  }), withCheckmark && selected ? /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    layout: _reactNativeReanimated.LinearTransition,
    entering: _reactNativeReanimated.FadeIn
  }, /*#__PURE__*/_react.default.createElement(_AnimatedSelectedIcon.AnimatedSelectedIcon, {
    width: iconSize,
    height: iconSize,
    strokeWidth: 2,
    stroke: appliedIconColor
  })) : null, Icon && withCheckmark && label && selected ? null : renderIconConditionally(), label ? /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.Text, {
    layout: _reactNativeReanimated.LinearTransition,
    style: [labelLarge, animatedLabelStyle, labelStyle]
  }, label) : null);
});
exports.ButtonSegment = ButtonSegment;
//# sourceMappingURL=ButtonSegment.component.js.map