"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styles = exports.getDynamicStyles = void 0;
var _reactNative = require("react-native");
var _convertToRgba = require("../../../utils/convert-to-rgba");
const styles = _reactNative.StyleSheet.create({
  outlinedContainer: {
    borderWidth: 1
  },
  elevatedContainer: {
    shadowOffset: {
      width: 0,
      height: 1
    },
    shadowOpacity: 0.15,
    shadowRadius: 3,
    elevation: 1
  }
});
exports.styles = styles;
const getDynamicStyles = (selected, elevated, disabled, theme) => {
  const labelDisabledColor = (0, _convertToRgba.convertToRGBA)(theme.surface.text, 0.38);
  const containerDisabledColor = (0, _convertToRgba.convertToRGBA)(theme.surface.textVariant, 0.12);
  const [disabledUnselectedBackgroundColorByType, disabledUnselectedBorderColorByType] = elevated ? [containerDisabledColor, 'transparent'] : ['transparent', containerDisabledColor];
  const [disabledBackgroundColor, disabledBorderColor] = selected ? [containerDisabledColor, 'transparent'] : [disabledUnselectedBackgroundColorByType, disabledUnselectedBorderColorByType];
  const enabledBackgroundColorByType = elevated ? theme.surfaceContainer.backgroundLow : 'transparent';
  const [enabledBackgroundColor, enabledBorderColor] = selected ? [theme.secondaryContainer.background, theme.secondaryContainer.background] : [enabledBackgroundColorByType, theme.outline];
  return _reactNative.StyleSheet.create(disabled ? {
    label: {
      color: labelDisabledColor
    },
    container: {
      borderColor: disabledBorderColor,
      backgroundColor: disabledBackgroundColor
    },
    icon: {
      color: labelDisabledColor
    },
    selectedIcon: {
      color: labelDisabledColor
    }
  } : {
    label: {
      color: theme.surface.text
    },
    container: {
      borderColor: enabledBorderColor,
      borderWidth: 1,
      backgroundColor: enabledBackgroundColor
    },
    icon: {
      color: theme.primary.background
    },
    selectedIcon: {
      color: theme.secondaryContainer.text
    }
  });
};
exports.getDynamicStyles = getDynamicStyles;
//# sourceMappingURL=filter-chip.styles.js.map