"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styles = exports.getDynamicStyles = void 0;
var _reactNative = require("react-native");
var _convertToRgba = require("../../../utils/convert-to-rgba");
const styles = _reactNative.StyleSheet.create({
  outlinedContainer: {
    borderWidth: 1
  },
  elevatedContainer: {
    shadowOffset: {
      width: 0,
      height: 1
    },
    shadowOpacity: 0.15,
    shadowRadius: 3,
    elevation: 1
  }
});
exports.styles = styles;
const getDynamicStyles = (selected, elevated, disabled, theme) => {
  const labelDisabledColor = (0, _convertToRgba.convertToRGBA)(theme.surface.text, 0.38);
  const containerDisabledColor = (0, _convertToRgba.convertToRGBA)(theme.surface.textVariant, 0.12);
  const [disabledUnselectedBackgroundColorByType, disabledUnselectedBorderColorByType] = elevated ? [containerDisabledColor, 'transparent'] : ['transparent', containerDisabledColor];
  const enabledBackgroundColorByType = elevated ? theme.surfaceContainer.backgroundLow : 'transparent';
  return _reactNative.StyleSheet.create(disabled ? {
    label: {
      color: labelDisabledColor
    },
    container: {
      borderColor: selected ? 'transparent' : disabledUnselectedBorderColorByType,
      backgroundColor: selected ? containerDisabledColor : disabledUnselectedBackgroundColorByType
    },
    icon: {
      color: labelDisabledColor
    }
  } : {
    label: {
      color: theme.surface.text
    },
    container: {
      borderColor: theme.outline,
      borderWidth: Number(!selected && !elevated),
      backgroundColor: selected ? theme.secondaryContainer.background : enabledBackgroundColorByType
    },
    icon: {
      color: theme.primary.background
    }
  });
};
exports.getDynamicStyles = getDynamicStyles;
//# sourceMappingURL=suggestion-chip.styles.js.map