"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _reactNative = require("react-native");
var _useTheme = require("../../../theme/useTheme.hook");
var _CheckSmallIcon = require("../../icons/check-small-icon/CheckSmallIcon.component");
var _checkbox = require("./checkbox.styles");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_CHECKBOX_SIZE = 24;
const CHECKMARK_SIZE_COEFF = 0.65;
const ERROR_ANIMATION_DURATION = 300;
const Checkbox = _ref => {
  let {
    value,
    checked,
    isError = false,
    labelEnd,
    labelStart,
    checkedIcon,
    errorColor,
    borderColor,
    checkedBorderColor,
    checkedBackgroundColor,
    style,
    checkboxStyle,
    size = DEFAULT_CHECKBOX_SIZE,
    errorAnimationDuration = ERROR_ANIMATION_DURATION,
    onCheck,
    ...props
  } = _ref;
  const errorAnim = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    surface,
    primary,
    error
  } = (0, _useTheme.useTheme)();
  const {
    checkboxFrame
  } = (0, _react.useMemo)(() => (0, _checkbox.getCheckboxFrameStyles)(size), [size]);
  const checkmarkSize = size * CHECKMARK_SIZE_COEFF;
  const icon = checkedIcon ?? /*#__PURE__*/_react.default.createElement(_CheckSmallIcon.CheckSmallIcon, {
    size: checkmarkSize
  });
  const disabledColorStyles = checked ? {
    backgroundColor: surface.text,
    borderColor: surface.text
  } : {
    backgroundColor: 'transparent',
    borderColor: surface.text
  };
  const [enabledBackgroundColor, enabledBorderColor] = checked ? [checkedBackgroundColor ?? primary.background, checkedBorderColor ?? primary.background] : ['transparent', borderColor ?? surface.textVariant];
  const checkboxColorsAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    backgroundColor: (0, _reactNativeReanimated.interpolateColor)(errorAnim.value, [0, 1], [enabledBackgroundColor, checked ? errorColor ?? error.background : 'transparent']),
    borderColor: (0, _reactNativeReanimated.interpolateColor)(errorAnim.value, [0, 1], [enabledBorderColor, errorColor ?? error.background])
  }), [enabledBackgroundColor, enabledBorderColor, errorColor, checked]);
  (0, _react.useEffect)(() => {
    errorAnim.value = (0, _reactNativeReanimated.withTiming)(isError ? 1 : 0, {
      duration: errorAnimationDuration
    });
  }, [isError, errorAnimationDuration]);
  const onPress = (0, _react.useCallback)(() => {
    onCheck(value);
  }, [onCheck, value]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({
    style: [_checkbox.styles.container, {
      opacity: props.disabled ? _checkbox.DISABLED_OPACITY : _checkbox.ENABLED_OPACITY
    }, style],
    onPress: onPress
  }, props), labelStart, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_checkbox.styles.checkbox, checkboxFrame, props.disabled ? disabledColorStyles : checkboxColorsAnimatedStyle, checkboxStyle]
  }, checked && icon), labelEnd);
};
exports.Checkbox = Checkbox;
//# sourceMappingURL=checkbox.component.js.map