"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioButton = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _useTheme = require("../../../theme/useTheme.hook");
var _radioButton = require("./radio-button.styles");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_RADIO_SIZE = 24;
const ANIMATION_DURATION = 150;
const RadioButton = _ref => {
  let {
    value,
    checked,
    labelEnd,
    labelStart,
    style,
    indicatorStyle,
    radioButtonStyle,
    size = DEFAULT_RADIO_SIZE,
    animationDuration = ANIMATION_DURATION,
    radioButtonColor,
    checkedRadioButtonColor,
    onCheck,
    ...props
  } = _ref;
  const anim = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    surface,
    primary
  } = (0, _useTheme.useTheme)();
  const frameStyles = (0, _react.useMemo)(() => (0, _radioButton.getRadioButtonFrameStyles)(size), [size]);
  const radioButtonAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    borderColor: (0, _reactNativeReanimated.interpolateColor)(anim.value, [0, 1], [radioButtonColor ?? surface.textVariant, checkedRadioButtonColor ?? primary.background])
  }), [radioButtonColor, checkedRadioButtonColor]);
  const indicatorAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    width: (0, _reactNativeReanimated.interpolate)(anim.value, [0, 1], [0, frameStyles.indicator.width]),
    height: (0, _reactNativeReanimated.interpolate)(anim.value, [0, 1], [0, frameStyles.indicator.width])
  }), []);
  (0, _react.useEffect)(() => {
    anim.value = (0, _reactNativeReanimated.withTiming)(checked ? 1 : 0, {
      duration: animationDuration
    });
  }, [checked, animationDuration]);
  const onPress = (0, _react.useCallback)(() => onCheck(value), [value, onCheck]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({
    onPress: onPress,
    style: [_radioButton.styles.container, {
      opacity: props.disabled ? _radioButton.DISABLED_OPACITY : _radioButton.ENABLED_OPACITY
    }, style]
  }, props), labelStart, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_radioButton.styles.radioButton, frameStyles.radioButton, props.disabled ? {
      borderColor: surface.text
    } : radioButtonAnimatedStyle, radioButtonStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [{
      borderRadius: frameStyles.indicator.borderRadius
    }, {
      backgroundColor: props.disabled ? surface.text : checkedRadioButtonColor ?? primary.background
    }, indicatorAnimatedStyle, indicatorStyle]
  })), labelEnd);
};
exports.RadioButton = RadioButton;
//# sourceMappingURL=RadioButton.component.js.map