"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Dialog = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _dialog = require("./dialog.styles");
var _useTheme = require("../../../theme/useTheme.hook");
var _ModalBackdropWrapper = require("../../modal-backdrop-wrapper/ModalBackdropWrapper.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_ANIMATION_DURATION = 220;
const Dialog = /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    style,
    children,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const [isVisible, setIsVisible] = (0, _react.useState)(false);
  const visibility = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  (0, _react.useImperativeHandle)(ref, () => ({
    close() {
      closeModal();
    },
    show() {
      setIsVisible(true);
      visibility.value = (0, _reactNativeReanimated.withTiming)(1, {
        duration: animationDuration
      });
    },
    isShowed() {
      return Boolean(visibility.value);
    }
  }), [animationDuration]);
  const closeModal = () => {
    visibility.value = (0, _reactNativeReanimated.withTiming)(0, {
      duration: animationDuration
    }, () => (0, _reactNativeReanimated.runOnJS)(setIsVisible)(false));
  };
  const dialogAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    transform: [{
      scale: (0, _reactNativeReanimated.interpolate)(visibility.value, [0, 1], [0.3, 1])
    }],
    opacity: visibility.value
  }), []);
  return /*#__PURE__*/_react.default.createElement(_ModalBackdropWrapper.ModalBackdropWrapper, {
    visibility: visibility,
    visible: isVisible,
    onRequestClose: closeModal
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({
    style: [_dialog.styles.dialog, {
      backgroundColor: surfaceContainer.backgroundHigh
    }, dialogAnimatedStyle, style]
  }, props), children));
});
exports.Dialog = Dialog;
//# sourceMappingURL=Dialog.component.js.map