"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FullScreenDialog = exports.AnimationType = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _useTheme = require("../../../theme/useTheme.hook");
var _fullScreenDialog = require("./full-screen-dialog.styles");
var _ModalBackdropWrapper = require("../../modal-backdrop-wrapper/ModalBackdropWrapper.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
let AnimationType = /*#__PURE__*/function (AnimationType) {
  AnimationType["SLIDE"] = "SLIDE";
  AnimationType["FADE"] = "FADE";
  AnimationType["ZOOM"] = "ZOOM";
  return AnimationType;
}({});
exports.AnimationType = AnimationType;
const ANIMATION_DURATION = 330;
const FullScreenDialog = /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    children,
    animationType = AnimationType.SLIDE,
    animationDuration = ANIMATION_DURATION,
    style,
    ...props
  } = _ref;
  const [isVisible, setIsVisible] = (0, _react.useState)(false);
  const [isClosing, setIsClosing] = (0, _react.useState)(false);
  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const visibility = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  const {
    height: windowHeight,
    width: windowWidth
  } = (0, _reactNative.useWindowDimensions)();
  (0, _react.useImperativeHandle)(ref, () => ({
    show() {
      if (isClosing) {
        setIsClosing(false);
      }
      setIsVisible(true);
      visibility.value = (0, _reactNativeReanimated.withTiming)(1, {
        duration: animationDuration
      });
    },
    close() {
      if (animationType === AnimationType.ZOOM) {
        setIsClosing(true);
      }
      visibility.value = (0, _reactNativeReanimated.withTiming)(0, {
        duration: animationDuration
      }, () => (0, _reactNativeReanimated.runOnJS)(setIsVisible)(false));
    },
    isShowed() {
      return Boolean(visibility.value);
    }
  }), [isClosing, animationType, animationDuration]);
  const dialogAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const slideAnimStyle = {
      transform: [{
        translateY: (0, _reactNativeReanimated.interpolate)(visibility.value, [0, 1], [windowHeight, 0])
      }],
      opacity: visibility.value
    };
    switch (animationType) {
      case AnimationType.SLIDE:
        return slideAnimStyle;
      case AnimationType.FADE:
        {
          return {
            opacity: visibility.value
          };
        }
      case AnimationType.ZOOM:
        {
          return isClosing ? slideAnimStyle : {
            transform: [{
              scale: (0, _reactNativeReanimated.interpolate)(visibility.value, [0, 1], [0.2, 1])
            }],
            opacity: visibility.value
          };
        }
      default:
        return slideAnimStyle;
    }
  }, [animationType, windowHeight, isClosing]);
  return /*#__PURE__*/_react.default.createElement(_ModalBackdropWrapper.ModalBackdropWrapper, {
    visibility: visibility,
    visible: isVisible,
    backdropStyle: _fullScreenDialog.styles.modalBackdropWrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({
    style: [_fullScreenDialog.styles.container, {
      height: windowHeight,
      width: windowWidth,
      paddingTop: insets.top,
      paddingBottom: insets.bottom,
      paddingLeft: insets.left,
      paddingRight: insets.right,
      backgroundColor: surfaceContainer.backgroundHigh
    }, dialogAnimatedStyle, style]
  }, props), children));
});
exports.FullScreenDialog = FullScreenDialog;
//# sourceMappingURL=FullScreenDialog.component.js.map