"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NavBarItem = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _navBarItem = require("./nav-bar-item.styles");
var _Badge = require("../../../badge/Badge.component");
var _useTheme = require("../../../../theme/useTheme.hook");
var _icon = require("../../../../constants/icon");
var _useTypography = require("../../../../typography/useTypography.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_LABEL_SIZE = 12;
const NavBarItem = _ref => {
  var _route$badge, _route$iconProps, _route$label;
  let {
    route,
    focused,
    fixedLabelVisibility,
    focusAnimDuration = 150,
    onPress,
    style,
    ...props
  } = _ref;
  const {
    surface,
    secondaryContainer
  } = (0, _useTheme.useTheme)();
  const {
    labelMediumProminent,
    labelMedium
  } = (0, _useTypography.useTypography)();
  const active = (0, _reactNativeReanimated.useSharedValue)(Number(focused));
  (0, _react.useEffect)(() => {
    active.value = (0, _reactNativeReanimated.withTiming)(Number(focused), {
      duration: focusAnimDuration
    });
  }, [focused, focusAnimDuration]);
  const iconContainerAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    opacity: active.value,
    transform: [{
      scale: (0, _reactNativeReanimated.interpolate)(active.value, [0, 1], [0.3, 1])
    }]
  }), []);
  const labelContainerAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    opacity: active.value,
    transform: [{
      translateY: (0, _reactNativeReanimated.interpolate)(active.value, [0, 1], [labelMedium.fontSize ?? DEFAULT_LABEL_SIZE, 0])
    }]
  }), [fixedLabelVisibility]);
  const Icon = focused ? route.selectedIcon : route.icon;
  const [iconColor, labelColor, labelTypography] = focused ? [secondaryContainer.text, surface.text, labelMediumProminent] : [surface.textVariant, surface.textVariant, labelMedium];
  const onRouteButtonPress = (0, _react.useCallback)(() => onPress(route.name), [route, onPress]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({
    style: [_navBarItem.styles.container, style],
    onPress: onRouteButtonPress,
    hitSlop: 12
  }, props), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_navBarItem.styles.iconWithBadge]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_navBarItem.styles.iconWithBadge, {
      backgroundColor: secondaryContainer.background
    }, _reactNative.StyleSheet.absoluteFillObject, iconContainerAnimatedStyle]
  }), route.showBadge || (_route$badge = route.badge) !== null && _route$badge !== void 0 && _route$badge.length ? /*#__PURE__*/_react.default.createElement(_Badge.Badge, {
    size: route.badgeSize,
    value: route.badge,
    style: [_navBarItem.styles.badge, {
      transform: [{
        translateX: (((_route$iconProps = route.iconProps) === null || _route$iconProps === void 0 ? void 0 : _route$iconProps.size) ?? _icon.DEFAULT_ICON_SIZE) - 8
      }]
    }]
  }) : null, /*#__PURE__*/_react.default.createElement(Icon, _extends({
    size: _icon.DEFAULT_ICON_SIZE,
    color: iconColor
  }, route.iconProps ?? {}))), (_route$label = route.label) !== null && _route$label !== void 0 && _route$label.length ? /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.Text, {
    style: [labelTypography, {
      color: labelColor
    }, fixedLabelVisibility ? {} : labelContainerAnimatedStyle]
  }, route.label) : null);
};
exports.NavBarItem = NavBarItem;
//# sourceMappingURL=NavBarItem.component.js.map