"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SecondaryTabs = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _secondaryTabs = require("./secondary-tabs.styles");
var _useTheme = require("../../../../theme/useTheme.hook");
var _Tab = require("../ui/tab/Tab.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const SecondaryTabs = _ref => {
  let {
    tabs,
    activeTab,
    badgeSize,
    scrollAnim,
    animConfig = {},
    tabStyle,
    badgeStyle,
    tabIconProps,
    tabTitleStyle,
    indicatorStyle,
    tabsContainerStyle,
    tabInnerContentStyle,
    ...props
  } = _ref;
  const {
    primary,
    outlineVariant
  } = (0, _useTheme.useTheme)();
  const activeTabIndex = tabs.findIndex(tab => tab.routeName === activeTab);
  const calcStartIndicatorPosition = (0, _react.useCallback)((totalTabsCount, targetTabIndex) => {
    'worklet';

    return 1 / totalTabsCount * targetTabIndex;
  }, []);
  const indicatorStartPos = (0, _reactNativeReanimated.useSharedValue)(calcStartIndicatorPosition(tabs.length, activeTabIndex));
  (0, _react.useEffect)(() => {
    indicatorStartPos.value = (0, _reactNativeReanimated.withSpring)(calcStartIndicatorPosition(tabs.length, activeTabIndex), {
      duration: 300,
      dampingRatio: 1.5,
      overshootClamping: true,
      restSpeedThreshold: 0.0001,
      ...animConfig
    });
  }, [activeTabIndex]);
  const indicatorAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const maxPosition = calcStartIndicatorPosition(tabs.length, tabs.length - 1);
    return {
      start: `${(0, _reactNativeReanimated.interpolate)(scrollAnim ? scrollAnim.value : indicatorStartPos.value, [0, maxPosition], [0, maxPosition * 100], _reactNativeReanimated.Extrapolation.CLAMP)}%`
    };
  }, [tabs]);
  const renderSecondaryTab = tab => /*#__PURE__*/_react.default.createElement(_Tab.Tab, _extends({
    key: tab.routeName
  }, tab, {
    type: _Tab.TabType.SECONDARY,
    active: tab.routeName === activeTab,
    iconProps: tabIconProps,
    badgeSize: badgeSize,
    badgeStyle: badgeStyle,
    titleStyle: tabTitleStyle,
    style: [_secondaryTabs.styles.tab, tab.style, tabStyle],
    innerContentStyle: tabInnerContentStyle
  }));
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [_secondaryTabs.styles.container, {
      borderBottomColor: outlineVariant
    }]
  }, props), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_secondaryTabs.styles.tabs, tabsContainerStyle]
  }, tabs.map(renderSecondaryTab)), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_secondaryTabs.styles.indicator, {
      backgroundColor: primary.background,
      width: `${100 / tabs.length}%`
    }, indicatorStyle, indicatorAnimatedStyle]
  }));
};
exports.SecondaryTabs = SecondaryTabs;
//# sourceMappingURL=SecondaryTabs.component.js.map