"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BottomSheet = void 0;
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _bottomSheet = require("./bottom-sheet.styles");
var _useTheme = require("../../../theme/useTheme.hook");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const AUTO_INCREASE_RANGE = 0.3;
const SWIPE_VELOCITY_THRESHOLD = 1000;
const DEFAULT_HEIGHT_COEFF = 0.4;
const DEFAULT_ANIMATION_DURATION = 300;
const BottomSheet = /*#__PURE__*/_react.default.forwardRef((_ref, ref) => {
  let {
    header,
    children,
    style,
    headerStyle,
    backdropStyle,
    dragHandleStyle,
    modalHeightCoeff = DEFAULT_HEIGHT_COEFF,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const {
    height
  } = (0, _reactNative.useWindowDimensions)();
  const {
    scrim,
    outline,
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  const windowHeight = _reactNative.Platform.select({
    ios: height,
    android: height + insets.top,
    default: height
  });
  const modalHeight = windowHeight * modalHeightCoeff;
  const [distanceToTop, autoIncreaseTresholdTop] = [windowHeight - modalHeight, windowHeight * AUTO_INCREASE_RANGE];
  const top = (0, _reactNativeReanimated.useSharedValue)(windowHeight);
  const context = (0, _reactNativeReanimated.useSharedValue)({
    diffY: windowHeight,
    touchStartY: 0
  });
  const scrollTo = (0, _react.useCallback)(destination => {
    'worklet';

    top.value = (0, _reactNativeReanimated.withTiming)(destination, {
      duration: animationDuration
    });
  }, [animationDuration]);
  (0, _react.useImperativeHandle)(ref, () => ({
    toggle: () => {
      scrollTo(top.value !== windowHeight ? windowHeight : distanceToTop);
    },
    expand: () => {
      scrollTo(insets.top);
    }
  }), [windowHeight]);
  const animatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: top.value
  }), []);
  const backgroundAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    opacity: (0, _reactNativeReanimated.interpolate)(top.value, [windowHeight, distanceToTop], [0, 0.32])
  }), [distanceToTop, windowHeight]);
  const backdropAnimatedProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    pointerEvents: top.value !== windowHeight ? 'auto' : 'none'
  }), [windowHeight]);
  const gesture = _reactNativeGestureHandler.Gesture.Pan().onStart(e => {
    context.value.diffY = top.value - e.absoluteY;
    context.value.touchStartY = e.absoluteY;
  }).onUpdate(e => {
    top.value = context.value.diffY + e.absoluteY;
  }).onEnd(e => {
    const swipeDown = e.velocityY > SWIPE_VELOCITY_THRESHOLD && e.absoluteY > context.value.touchStartY;
    const swipeUp = e.velocityY < -SWIPE_VELOCITY_THRESHOLD;
    if (swipeDown || top.value > distanceToTop) {
      scrollTo(windowHeight);
    } else if (swipeUp || top.value < autoIncreaseTresholdTop) {
      scrollTo(insets.top);
    }
  });
  const closeModal = (0, _react.useCallback)(() => {
    scrollTo(windowHeight);
  }, [windowHeight]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    onTouchStart: closeModal,
    animatedProps: backdropAnimatedProps,
    style: [_bottomSheet.styles.backdrop, {
      backgroundColor: scrim
    }, backgroundAnimatedStyle, backdropStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: gesture
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({
    style: [_bottomSheet.styles.bottomSheet, {
      backgroundColor: surfaceContainer.backgroundLow
    }, animatedStyle, style]
  }, props), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_bottomSheet.styles.header, headerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_bottomSheet.styles.dragHandle, {
      backgroundColor: outline
    }, dragHandleStyle]
  }), header), children)));
});
exports.BottomSheet = BottomSheet;
//# sourceMappingURL=BottomSheet.component.js.map