"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SideSheet = void 0;
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _sideSheet = require("./side-sheet.styles");
var _useTheme = require("../../../theme/useTheme.hook");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DEFAULT_ANIMATION_DURATION = 300;
const DEFAULT_WIDTH_COEFF = 0.85;
const SideSheet = /*#__PURE__*/_react.default.forwardRef((_ref, ref) => {
  let {
    children,
    style,
    backdropStyle,
    stickySide = 'right',
    modalWidthCoeff = DEFAULT_WIDTH_COEFF,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const {
    scrim,
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  const {
    width: windowWidth
  } = (0, _reactNative.useWindowDimensions)();
  const modalWidth = windowWidth * modalWidthCoeff;
  const onOpenDistanceToEdge = windowWidth - modalWidth;
  const edge = (0, _reactNativeReanimated.useSharedValue)(windowWidth);
  const diffX = (0, _reactNativeReanimated.useSharedValue)(modalWidth);
  const scrollTo = (0, _react.useCallback)(destination => {
    'worklet';

    edge.value = (0, _reactNativeReanimated.withTiming)(destination, {
      duration: animationDuration
    });
  }, [animationDuration]);
  (0, _react.useImperativeHandle)(ref, () => ({
    toggle: () => {
      scrollTo(edge.value !== windowWidth ? windowWidth : onOpenDistanceToEdge);
    }
  }), [onOpenDistanceToEdge, windowWidth]);
  const leftSideSheetAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    right: edge.value
  }), []);
  const rightSideSheetAtyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    left: edge.value
  }), []);
  const backgroundAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    opacity: (0, _reactNativeReanimated.interpolate)(edge.value, [windowWidth, onOpenDistanceToEdge], [0, 0.32])
  }), [onOpenDistanceToEdge, windowWidth]);
  const backdropAnimatedProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    pointerEvents: edge.value !== windowWidth ? 'auto' : 'none'
  }), [windowWidth]);
  const gesture = _reactNativeGestureHandler.Gesture.Pan().onStart(e => {
    diffX.value = stickySide === 'right' ? e.absoluteX - edge.value : windowWidth - e.absoluteX - edge.value;
  }).onUpdate(e => {
    if (stickySide === 'right') {
      edge.value = e.absoluteX - diffX.value;
    }
    if (stickySide === 'left') {
      edge.value = windowWidth - e.absoluteX - diffX.value;
    }
  }).onEnd(() => {
    const closeTreshold = onOpenDistanceToEdge + windowWidth * 0.2;
    if (edge.value > closeTreshold) {
      scrollTo(windowWidth);
    } else {
      scrollTo(onOpenDistanceToEdge);
    }
  });
  const closeModal = (0, _react.useCallback)(() => {
    scrollTo(windowWidth);
  }, [windowWidth]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    onTouchStart: closeModal,
    animatedProps: backdropAnimatedProps,
    style: [_sideSheet.styles.backdrop, {
      backgroundColor: scrim
    }, backgroundAnimatedStyle, backdropStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: gesture
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({
    style: [_sideSheet.styles.sideSheet, {
      backgroundColor: surfaceContainer.backgroundLow
    }, stickySide === 'right' ? [_sideSheet.styles.rightSideSheet, rightSideSheetAtyle] : [_sideSheet.styles.leftSideSheet, leftSideSheetAnimatedStyle], style]
  }, props), children)));
});
exports.SideSheet = SideSheet;
//# sourceMappingURL=SideSheet.component.js.map