"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RangeSlider = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _rangeSlider = require("./range-slider.styles");
var _useRangeSlider = require("./useRangeSlider.hook");
var _useSliderColors = require("../use-slider-colors.hook");
var _SliderTrack = require("../ui/slider-track/SliderTrack.component");
var _useRangeSliderTrackPoints = require("./useRangeSliderTrackPoints.hook");
var _SliderIndicator = require("../ui/slider-indicator/SliderIndicator.component");
var _SliderTrackPoint = require("../ui/slider-track-point/SliderTrackPoint.component");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const RangeSlider = _ref => {
  let {
    max,
    min,
    step,
    range = [0, 0],
    damping = 20,
    centered = false,
    disabled = false,
    thumbStyle,
    valueStyle,
    indicatorStyle,
    trackPointStyle,
    trackPointsStyle,
    filledTrackStyle,
    remainingTrackStyle,
    valueHeight,
    thumbWidthActive,
    thumbWidthInactive,
    onChangeRange,
    onLayout,
    style,
    ...props
  } = _ref;
  const {
    filledTrackColor,
    remainingTrackColor
  } = (0, _useSliderColors.useSliderColors)(disabled, centered);
  const trackPoints = (0, _useRangeSliderTrackPoints.useRangeSliderTrackPoints)({
    max,
    min,
    step,
    centered
  });
  const {
    gesture,
    selectedRange,
    thumbMinSliding,
    thumbMaxSliding,
    animMinValueProps,
    animMaxValueProps,
    filledTrackAnimatedStyle,
    remainingTrackAfterAnimatedStyle,
    remainingTrackBeforeAnimatedStyle,
    slideToTrackPoint,
    setUpSliderLayout
  } = (0, _useRangeSlider.useRangeSlider)({
    max,
    min,
    centered,
    step,
    damping
  }, range, onChangeRange);
  const handleLayoutChange = e => {
    setUpSliderLayout(e);
    if (onLayout) {
      onLayout(e);
    }
  };
  const renderTrackPoint = pointValue => /*#__PURE__*/_react.default.createElement(_SliderTrackPoint.SliderTrackPoint, {
    key: pointValue,
    value: pointValue,
    disabled: disabled,
    selectedValue: selectedRange,
    onPress: slideToTrackPoint,
    style: trackPointStyle
  });
  return /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: gesture.enabled(!disabled)
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [_rangeSlider.styles.container, style],
    onLayout: handleLayoutChange
  }, props), /*#__PURE__*/_react.default.createElement(_SliderTrack.SliderTrack, {
    style: [{
      backgroundColor: remainingTrackColor
    }, _rangeSlider.styles.remainingBeforeTrack, remainingTrackBeforeAnimatedStyle, filledTrackStyle]
  }), /*#__PURE__*/_react.default.createElement(_SliderIndicator.SliderIndicator, {
    animValueProps: animMinValueProps,
    sliding: thumbMinSliding,
    disabled: disabled,
    style: [_rangeSlider.styles.thumb, indicatorStyle],
    thumbStyle: thumbStyle,
    valueStyle: valueStyle,
    valueHeight: valueHeight,
    thumbWidthActive: thumbWidthActive,
    thumbWidthInactive: thumbWidthInactive
  }), /*#__PURE__*/_react.default.createElement(_SliderTrack.SliderTrack, {
    style: [{
      backgroundColor: filledTrackColor
    }, _rangeSlider.styles.filledTrack, filledTrackAnimatedStyle, filledTrackStyle]
  }), /*#__PURE__*/_react.default.createElement(_SliderIndicator.SliderIndicator, {
    animValueProps: animMaxValueProps,
    sliding: thumbMaxSliding,
    disabled: disabled,
    style: [_rangeSlider.styles.thumb, indicatorStyle],
    thumbStyle: thumbStyle,
    valueStyle: valueStyle,
    valueHeight: valueHeight,
    thumbWidthActive: thumbWidthActive,
    thumbWidthInactive: thumbWidthInactive
  }), /*#__PURE__*/_react.default.createElement(_SliderTrack.SliderTrack, {
    style: [{
      backgroundColor: remainingTrackColor
    }, _rangeSlider.styles.remainingAfterTrack, remainingTrackAfterAnimatedStyle, remainingTrackStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_rangeSlider.styles.trackPoints, trackPointsStyle]
  }, trackPoints.map(renderTrackPoint))));
};
exports.RangeSlider = RangeSlider;
//# sourceMappingURL=RangeSlider.component.js.map