"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useRangeSlider = void 0;
var _react = require("react");
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _reactNativeReanimated = require("react-native-reanimated");
var _normalize = require("../worklets/normalize.worklet");
var _validateSliderRange = require("./validate-slider-range");
var _calcTranslationXBasedOnValue = require("../worklets/calc-translationX-based-on-value.worklet");
var ThumbType = /*#__PURE__*/function (ThumbType) {
  ThumbType["MIN"] = "MIN";
  ThumbType["MAX"] = "MAX";
  return ThumbType;
}(ThumbType || {});
const useRangeSlider = (_ref, range, onChangeRange) => {
  let {
    max,
    min,
    step,
    damping
  } = _ref;
  const [sliderLayout, setSliderLayout] = (0, _react.useState)({
    width: 0,
    height: 0,
    x: 0,
    y: 0
  });
  const [minValue, maxValue] = [range[0] ?? 0, range[1] ?? 0];
  const thumbMinSliding = (0, _reactNativeReanimated.useSharedValue)(0);
  const thumbMaxSliding = (0, _reactNativeReanimated.useSharedValue)(0);
  const thumbMinTranslationX = (0, _reactNativeReanimated.useSharedValue)(0);
  const thumbMaxTranslationX = (0, _reactNativeReanimated.useSharedValue)(0);
  const thumbsTranslationXContext = (0, _reactNativeReanimated.useSharedValue)({
    min: 0,
    max: 0
  });
  const selectedRange = (0, _reactNativeReanimated.useSharedValue)([minValue, maxValue]);
  (0, _react.useEffect)(() => {
    (0, _validateSliderRange.validateSliderRange)(range);
    adjustThumbsPosition(sliderLayout.width);
  }, [range, sliderLayout]);
  const filledTrackAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const remainingTrackFlex = (0, _reactNativeReanimated.interpolate)(thumbMinTranslationX.value, [0, sliderLayout.width], [0, 1]);
    const remainingTrackAfterFlex = (0, _reactNativeReanimated.interpolate)(thumbMaxTranslationX.value, [0, sliderLayout.width], [0, 1]);
    return {
      flex: Math.abs(remainingTrackFlex - remainingTrackAfterFlex)
    };
  }, [sliderLayout]);
  const remainingTrackBeforeAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    flex: (0, _reactNativeReanimated.interpolate)(thumbMinTranslationX.value, [0, sliderLayout.width], [0, 1])
  }), [sliderLayout]);
  const remainingTrackAfterAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    flex: (0, _reactNativeReanimated.interpolate)(thumbMaxTranslationX.value, [0, sliderLayout.width], [1, 0])
  }), [sliderLayout]);
  const calcValueBasedOnThumbTranslationX = (translationX, thumbType) => {
    'worklet';

    const value = Math.round((0, _reactNativeReanimated.interpolate)(translationX, [0, sliderLayout.width], [min, max]));
    const normalizedValue = (0, _normalize.normalize)(value, step);
    selectedRange.value = thumbType === ThumbType.MIN ? [normalizedValue, selectedRange.value[1] ?? 0] : [selectedRange.value[0] ?? 0, normalizedValue];
    return normalizedValue;
  };
  const updateTranslationX = (thumbTranslationX, translationX) => {
    'worklet';

    if (step) {
      const stepSize = sliderLayout.width / (max - min) * step;
      const stepSnap = (0, _normalize.normalize)(translationX, stepSize);
      thumbTranslationX.value = stepSnap;
    } else {
      thumbTranslationX.value = translationX;
    }
  };
  const gesture = _reactNativeGestureHandler.Gesture.Pan().onStart(e => {
    const touchX = e.x - sliderLayout.x;
    const distanceToMinThumb = Math.abs(touchX - thumbMinTranslationX.value);
    const distanceToMaxThumb = Math.abs(touchX - thumbMaxTranslationX.value);
    const activeThumb = touchX < thumbMaxTranslationX.value && distanceToMinThumb <= distanceToMaxThumb ? thumbMinSliding : thumbMaxSliding;
    activeThumb.value = (0, _reactNativeReanimated.withTiming)(1);
  }).onUpdate(e => {
    if (thumbMinSliding.value) {
      const currentMinTranslationX = Math.max(0, Math.min(thumbMaxTranslationX.value, e.translationX + thumbsTranslationXContext.value.min));
      updateTranslationX(thumbMinTranslationX, currentMinTranslationX);
    } else if (thumbMaxSliding.value) {
      const currentMaxTranslationX = Math.min(sliderLayout.width, Math.max(thumbMinTranslationX.value, e.translationX + thumbsTranslationXContext.value.max));
      updateTranslationX(thumbMaxTranslationX, currentMaxTranslationX);
    }
  }).onEnd(() => {
    thumbMinSliding.value = (0, _reactNativeReanimated.withTiming)(0);
    thumbMaxSliding.value = (0, _reactNativeReanimated.withTiming)(0);
    thumbsTranslationXContext.value = {
      min: thumbMinTranslationX.value,
      max: thumbMaxTranslationX.value
    };
    if (onChangeRange) {
      (0, _reactNativeReanimated.runOnJS)(onChangeRange)(selectedRange.value);
    }
  });
  const setUpSliderLayout = e => {
    const layout = e.nativeEvent.layout;
    adjustThumbsPosition(layout.width);
    setSliderLayout(layout);
  };
  const adjustThumbsPosition = width => {
    const initialMinTthumbTranslationX = (0, _calcTranslationXBasedOnValue.calcTranslationXBasedOnValue)({
      min,
      max
    }, (0, _normalize.normalize)(minValue, step), width);
    const initiaMaxTthumbTranslationX = (0, _calcTranslationXBasedOnValue.calcTranslationXBasedOnValue)({
      min,
      max
    }, (0, _normalize.normalize)(maxValue, step), width);
    thumbMinTranslationX.value = (0, _reactNativeReanimated.withSpring)(initialMinTthumbTranslationX, {
      damping
    });
    thumbMaxTranslationX.value = (0, _reactNativeReanimated.withSpring)(initiaMaxTthumbTranslationX, {
      damping
    });
    thumbsTranslationXContext.value = {
      min: initialMinTthumbTranslationX,
      max: initiaMaxTthumbTranslationX
    };
  };
  const slideToTrackPoint = pointValue => {
    if (typeof selectedRange.value[0] !== 'number' || typeof selectedRange.value[1] !== 'number') {
      return;
    }
    const diffFromMinThumb = Math.abs(pointValue - selectedRange.value[0]);
    const diffFromMaxThumb = Math.abs(pointValue - selectedRange.value[1]);
    let [activeThumbSliding, activeThumbTranslationX] = [thumbMaxSliding, thumbMaxTranslationX];
    if (diffFromMinThumb === diffFromMaxThumb) {
      [activeThumbSliding, activeThumbTranslationX] = pointValue < selectedRange.value[0] ? [thumbMinSliding, thumbMinTranslationX] : [thumbMaxSliding, thumbMaxTranslationX];
    } else if (diffFromMinThumb < diffFromMaxThumb) {
      [activeThumbSliding, activeThumbTranslationX] = [thumbMinSliding, thumbMinTranslationX];
    }
    const thumbPointValueTranslationX = (0, _calcTranslationXBasedOnValue.calcTranslationXBasedOnValue)({
      min,
      max
    }, pointValue, sliderLayout.width);
    activeThumbSliding.value = (0, _reactNativeReanimated.withTiming)(1);
    activeThumbTranslationX.value = (0, _reactNativeReanimated.withSpring)(thumbPointValueTranslationX, {
      damping
    }, () => {
      activeThumbSliding.value = (0, _reactNativeReanimated.withTiming)(0);
      thumbsTranslationXContext.value = {
        min: thumbMinTranslationX.value,
        max: thumbMaxTranslationX.value
      };
      if (onChangeRange) {
        (0, _reactNativeReanimated.runOnJS)(onChangeRange)(selectedRange.value);
      }
    });
  };
  const animMinValueProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    text: `${calcValueBasedOnThumbTranslationX(thumbMinTranslationX.value, ThumbType.MIN)}`
  }));
  const animMaxValueProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    text: `${calcValueBasedOnThumbTranslationX(thumbMaxTranslationX.value, ThumbType.MAX)}`
  }));
  return {
    gesture,
    selectedRange,
    thumbMinSliding,
    thumbMaxSliding,
    animMinValueProps,
    animMaxValueProps,
    filledTrackAnimatedStyle,
    remainingTrackAfterAnimatedStyle,
    remainingTrackBeforeAnimatedStyle,
    setUpSliderLayout,
    slideToTrackPoint
  };
};
exports.useRangeSlider = useRangeSlider;
//# sourceMappingURL=useRangeSlider.hook.js.map