"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Slider = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _slider = require("./slider.styles");
var _useSlider = require("./useSlider.hook");
var _useSliderColors = require("../use-slider-colors.hook");
var _useSliderTrackPoints = require("./useSliderTrackPoints.hook");
var _SliderTrack = require("../ui/slider-track/SliderTrack.component");
var _SliderIndicator = require("../ui/slider-indicator/SliderIndicator.component");
var _SliderTrackPoint = require("../ui/slider-track-point/SliderTrackPoint.component");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const Slider = _ref => {
  let {
    max,
    min,
    step,
    value = 0,
    damping = 20,
    disabled = false,
    centered = false,
    thumbStyle,
    valueStyle,
    indicatorStyle,
    trackPointStyle,
    trackPointsStyle,
    filledTrackStyle,
    remainingTrackStyle,
    valueHeight,
    thumbWidthActive,
    thumbWidthInactive,
    onChangeValue,
    onLayout,
    style,
    ...props
  } = _ref;
  const {
    filledTrackColor,
    remainingTrackColor
  } = (0, _useSliderColors.useSliderColors)(disabled, centered);
  const trackPoints = (0, _useSliderTrackPoints.useSliderTrackPoints)({
    max,
    min,
    step,
    centered
  });
  const {
    gesture,
    sliding,
    selectedValue,
    animValueProps,
    filledTrackAnimatedStyle,
    remainingTrackAnimatedStyle,
    slideToTrackPoint,
    setUpSliderLayout
  } = (0, _useSlider.useSlider)({
    max,
    min,
    step,
    damping
  }, value, onChangeValue);
  const trackPointsJustifyContent = trackPoints.length > 1 ? 'space-between' : 'flex-end';
  const handleLayoutChange = e => {
    setUpSliderLayout(e.nativeEvent.layout.width);
    if (onLayout) {
      onLayout(e);
    }
  };
  const renderTrackPoint = pointValue => /*#__PURE__*/_react.default.createElement(_SliderTrackPoint.SliderTrackPoint, {
    key: pointValue,
    value: pointValue,
    selectedValue: selectedValue,
    disabled: disabled,
    onPress: slideToTrackPoint,
    disableColorChange: centered,
    style: trackPointStyle
  });
  return /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: gesture.enabled(!disabled)
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [_slider.styles.container, style],
    onLayout: handleLayoutChange
  }, props), /*#__PURE__*/_react.default.createElement(_SliderTrack.SliderTrack, {
    style: [{
      backgroundColor: filledTrackColor
    }, _slider.styles.filledTrack, filledTrackAnimatedStyle, filledTrackStyle]
  }), /*#__PURE__*/_react.default.createElement(_SliderIndicator.SliderIndicator, {
    sliding: sliding,
    disabled: disabled,
    animValueProps: animValueProps,
    style: [_slider.styles.thumb, indicatorStyle],
    thumbStyle: thumbStyle,
    valueStyle: valueStyle,
    valueHeight: valueHeight,
    thumbWidthActive: thumbWidthActive,
    thumbWidthInactive: thumbWidthInactive
  }), /*#__PURE__*/_react.default.createElement(_SliderTrack.SliderTrack, {
    style: [{
      backgroundColor: remainingTrackColor
    }, _slider.styles.remainingTrack, remainingTrackAnimatedStyle, remainingTrackStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_slider.styles.trackPoints, {
      justifyContent: trackPointsJustifyContent
    }, trackPointsStyle]
  }, trackPoints.map(renderTrackPoint))));
};
exports.Slider = Slider;
//# sourceMappingURL=Slider.component.js.map