"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSlider = void 0;
var _react = require("react");
var _reactNativeGestureHandler = require("react-native-gesture-handler");
var _reactNativeReanimated = require("react-native-reanimated");
var _normalize = require("../worklets/normalize.worklet");
var _calcTranslationXBasedOnValue = require("../worklets/calc-translationX-based-on-value.worklet");
const useSlider = (_ref, value, onChangeValue) => {
  let {
    max,
    min,
    step,
    damping
  } = _ref;
  const [sliderWidth, setSliderWith] = (0, _react.useState)(0);
  const sliding = (0, _reactNativeReanimated.useSharedValue)(0);
  const selectedValue = (0, _reactNativeReanimated.useSharedValue)(value);
  const thumbTranslationX = (0, _reactNativeReanimated.useSharedValue)(0);
  const thumbTranslationXContext = (0, _reactNativeReanimated.useSharedValue)(0);
  const filledTrackAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    flex: (0, _reactNativeReanimated.interpolate)(thumbTranslationX.value, [0, sliderWidth], [0, 1])
  }), [sliderWidth]);
  const remainingTrackAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    flex: (0, _reactNativeReanimated.interpolate)(thumbTranslationX.value, [0, sliderWidth], [1, 0])
  }), [sliderWidth]);
  (0, _react.useEffect)(() => {
    adjustThumbPosition(sliderWidth);
  }, [value, sliderWidth]);
  const calcValueBasedOnThumbTranslationX = translationX => {
    'worklet';

    const valueBaseOnThumbTranslateX = Math.round((0, _reactNativeReanimated.interpolate)(translationX, [0, sliderWidth], [min, max]));
    const normalizedValue = (0, _normalize.normalize)(valueBaseOnThumbTranslateX, step);
    selectedValue.value = normalizedValue;
    return normalizedValue;
  };
  const gesture = _reactNativeGestureHandler.Gesture.Pan().onStart(() => {
    sliding.value = (0, _reactNativeReanimated.withTiming)(1);
  }).onUpdate(e => {
    const currentTranslationX = Math.max(0, Math.min(Math.round(thumbTranslationXContext.value + e.translationX), sliderWidth));
    if (step) {
      const stepSize = sliderWidth / (max - min) * step;
      const stepSnap = (0, _normalize.normalize)(currentTranslationX, stepSize);
      thumbTranslationX.value = stepSnap;
    } else {
      thumbTranslationX.value = currentTranslationX;
    }
  }).onEnd(() => {
    thumbTranslationXContext.value = thumbTranslationX.value;
    sliding.value = (0, _reactNativeReanimated.withTiming)(0);
    if (onChangeValue) {
      const valueBasedOnPos = calcValueBasedOnThumbTranslationX(thumbTranslationX.value);
      (0, _reactNativeReanimated.runOnJS)(onChangeValue)(valueBasedOnPos);
    }
  });
  const setUpSliderLayout = width => {
    adjustThumbPosition(width);
    setSliderWith(width);
  };
  const adjustThumbPosition = width => {
    const initialTthumbTranslationX = (0, _calcTranslationXBasedOnValue.calcTranslationXBasedOnValue)({
      min,
      max
    }, (0, _normalize.normalize)(value, step), width);
    thumbTranslationX.value = (0, _reactNativeReanimated.withSpring)(initialTthumbTranslationX, {
      damping
    });
    thumbTranslationXContext.value = initialTthumbTranslationX;
  };
  const slideToTrackPoint = pointValue => {
    const thumbPointValueTranslationX = (0, _calcTranslationXBasedOnValue.calcTranslationXBasedOnValue)({
      min,
      max
    }, pointValue, sliderWidth);
    sliding.value = (0, _reactNativeReanimated.withTiming)(1);
    thumbTranslationX.value = (0, _reactNativeReanimated.withSpring)(thumbPointValueTranslationX, {
      damping
    }, () => {
      sliding.value = (0, _reactNativeReanimated.withTiming)(0);
      thumbTranslationXContext.value = thumbPointValueTranslationX;
      if (onChangeValue) {
        (0, _reactNativeReanimated.runOnJS)(onChangeValue)(pointValue);
      }
    });
  };
  const animValueProps = (0, _reactNativeReanimated.useAnimatedProps)(() => ({
    text: `${calcValueBasedOnThumbTranslationX(thumbTranslationX.value)}`
  }));
  return {
    gesture,
    sliding,
    animValueProps,
    selectedValue,
    filledTrackAnimatedStyle,
    remainingTrackAnimatedStyle,
    slideToTrackPoint,
    setUpSliderLayout
  };
};
exports.useSlider = useSlider;
//# sourceMappingURL=useSlider.hook.js.map