"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Snackbar = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _reactNative = require("react-native");
var _snackbar = require("./snackbar.styles");
var _useTheme = require("../../theme/useTheme.hook");
var _CloseIcon = require("../icons/close-icon/CloseIcon.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DISAPPEAR_COEFF = 0.5;
const DEFAULT_OFFSET = 64;
const DEFAULT_ICON_SIZE = 20;
const DEFAULT_SHOW_DURATION = 2000;
const DEFAULT_ANIMATION_DURATION = 500;
const Snackbar = /*#__PURE__*/_react.default.forwardRef((_ref, ref) => {
  let {
    content,
    action = '',
    showCloseIcon = false,
    offset = DEFAULT_OFFSET,
    duration = DEFAULT_SHOW_DURATION,
    style,
    actionStyle,
    contentStyle,
    closeIconColor,
    closeIconSize = DEFAULT_ICON_SIZE,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    onActionPress,
    ...props
  } = _ref;
  const visibility = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    primary,
    surface
  } = (0, _useTheme.useTheme)();
  const timeout = (0, _react.useRef)(null);
  const hideSnackbar = (0, _react.useCallback)(() => {
    visibility.value = (0, _reactNativeReanimated.withTiming)(0, {
      duration: animationDuration
    });
    if (timeout.current) {
      clearTimeout(timeout.current);
    }
  }, [animationDuration, timeout.current]);
  (0, _react.useEffect)(() => hideSnackbar, []);
  (0, _react.useImperativeHandle)(ref, () => ({
    show() {
      visibility.value = (0, _reactNativeReanimated.withTiming)(1, {
        duration: animationDuration
      });
      timeout.current = setTimeout(() => {
        hideSnackbar();
      }, duration);
    },
    dismiss() {
      hideSnackbar();
      timeout.current = null;
    }
  }), [hideSnackbar, animationDuration, duration]);
  const snackbarAnimatedStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    opacity: visibility.value,
    bottom: (0, _reactNativeReanimated.interpolate)(visibility.value, [0, 1], [offset * DISAPPEAR_COEFF, offset])
  }), [offset]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({
    style: [_snackbar.styles.container, {
      backgroundColor: surface.backgroundInverse
    }, snackbarAnimatedStyle, style]
  }, props), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [{
      color: surface.textInverse
    }, _snackbar.styles.supportingText, contentStyle]
  }, content), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _snackbar.styles.actions
  }, action.length > 0 && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    hitSlop: 16,
    onPress: onActionPress
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [{
      color: primary.backgroundInverse
    }, _snackbar.styles.mainAction, actionStyle]
  }, action)), showCloseIcon && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    hitSlop: 16,
    onPress: hideSnackbar
  }, /*#__PURE__*/_react.default.createElement(_CloseIcon.CloseIcon, {
    size: closeIconSize,
    color: closeIconColor ?? surface.text
  }))));
});
exports.Snackbar = Snackbar;
//# sourceMappingURL=Snackbar.component.js.map