"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FilledTextInput = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _reactNative = require("react-native");
var _icons = require("../../icons");
var _filledTextInput = require("./filled-text-input.styles");
var _useTextInputColors = require("../use-text-input-colors.hook");
var _useTextInputFocusAnim = require("../use-text-input-focus-anim.hook");
var _useTypography = require("../../../typography/useTypography.component");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const UNFOCUSED_LABEL_TOP_PLACEMENT = 8;
const DEFAULT_LABEL_SMALL_FONT_SIZE = 12;
const DEFAULT_LABEL_LARGE_FONT_SIZE = 16;
const ACTIVE_INDICATOR_FOCUSED_HEIGHT = 3;
const ACTIVE_INDICATOR_UNFOCUSED_HEIGHT = 1;
const FilledTextInput = /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    label,
    placeholder,
    errorText,
    suportingText,
    disabled = false,
    leadingIcon,
    trailingIcon,
    leadingIconProps = {},
    trailingIconProps = {},
    leadingComponent,
    trailingComponent,
    style,
    labelStyle,
    outerContainerStyle,
    innerContainerStyle,
    supportingTextStyle,
    activeIndicatorStyle,
    onFocus,
    onBlur,
    onOuterContainerLayout,
    ...props
  } = _ref;
  const {
    bodyLarge,
    bodySmall
  } = (0, _useTypography.useTypography)();
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const inputRef = ref || (0, _react.useRef)(null);
  const {
    valueColor,
    containerColor,
    selectionColor,
    placeholderColor,
    labelFocusedColor,
    trailingIconColor,
    leadingIconColor,
    labelUnfocusedColor,
    supportingTextColor,
    activeIndicatorFocusedColor,
    activeIndicatorUnfocusedColor
  } = (0, _useTextInputColors.useTextInputColors)({
    disabled,
    isError: ((errorText === null || errorText === void 0 ? void 0 : errorText.length) ?? 0) > 0
  });
  const {
    focusAnim,
    focusAnimRange,
    focusInput,
    onInputBlur,
    onInputFocus
  } = (0, _useTextInputFocusAnim.useTextInputFocus)({
    inputRef,
    onBlur,
    onFocus
  });
  const LeadingIcon = leadingIcon;
  const TrailingIcon = errorText ? _icons.ErrorIcon : trailingIcon;
  const [smallLabelFontSize, largeLabelFontSize] = [bodySmall.fontSize ?? DEFAULT_LABEL_SMALL_FONT_SIZE, bodyLarge.fontSize ?? DEFAULT_LABEL_LARGE_FONT_SIZE];
  const [unfocusedLabelFontSize, unfocusedLabelTopPlacement] = placeholder ? [smallLabelFontSize, 0] : [largeLabelFontSize, UNFOCUSED_LABEL_TOP_PLACEMENT];
  const labelAnimatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelTopPlacement, 0]),
    color: (0, _reactNativeReanimated.interpolateColor)(focusAnim.value, focusAnimRange, [labelUnfocusedColor, labelFocusedColor]),
    fontSize: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelFontSize, smallLabelFontSize])
  }), [labelUnfocusedColor, labelFocusedColor, unfocusedLabelTopPlacement, unfocusedLabelFontSize, smallLabelFontSize]);
  const activeIndicatorAnimatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    backgroundColor: (0, _reactNativeReanimated.interpolateColor)(focusAnim.value, focusAnimRange, [activeIndicatorUnfocusedColor, activeIndicatorFocusedColor]),
    height: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [ACTIVE_INDICATOR_UNFOCUSED_HEIGHT, ACTIVE_INDICATOR_FOCUSED_HEIGHT])
  }), [activeIndicatorUnfocusedColor, activeIndicatorFocusedColor]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: outerContainerStyle,
    onLayout: onOuterContainerLayout
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    onPress: focusInput
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_filledTextInput.styles.container, {
      backgroundColor: containerColor
    }, innerContainerStyle]
  }, leadingComponent, LeadingIcon ? /*#__PURE__*/_react.default.createElement(LeadingIcon, _extends({
    color: leadingIconColor,
    style: _filledTextInput.styles.leadingIcon
  }, leadingIconProps)) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_filledTextInput.styles.inputWithLabelContainer]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.Text, {
    style: [_filledTextInput.styles.label, bodyLarge, labelAnimatedStyles, labelStyle]
  }, label), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    ref: inputRef,
    onBlur: onInputBlur,
    onFocus: onInputFocus,
    editable: !disabled,
    placeholder: placeholder,
    selectionColor: selectionColor,
    placeholderTextColor: placeholderColor,
    style: [_filledTextInput.styles.input, bodyLarge, {
      color: valueColor
    }, style]
  }, props))), TrailingIcon ? /*#__PURE__*/_react.default.createElement(TrailingIcon, _extends({
    color: trailingIconColor,
    style: _filledTextInput.styles.trailingIcon
  }, trailingIconProps)) : null, trailingComponent, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_filledTextInput.styles.activeIndicator, activeIndicatorAnimatedStyles, activeIndicatorStyle]
  }))), suportingText || errorText ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [bodySmall, _filledTextInput.styles.supportingText, {
      color: supportingTextColor
    }, supportingTextStyle]
  }, errorText ?? suportingText) : null);
});
exports.FilledTextInput = FilledTextInput;
//# sourceMappingURL=FilledTextInput.component.js.map