"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OutlinedTextInput = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _reactNative = require("react-native");
var _icons = require("../../icons");
var _useTheme = require("../../../theme/useTheme.hook");
var _useTextInputColors = require("../use-text-input-colors.hook");
var _useTextInputFocusAnim = require("../use-text-input-focus-anim.hook");
var _useTypography = require("../../../typography/useTypography.component");
var _outlinedTextInput = require("./outlined-text-input.styles");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const BORDER_FOCUSED_WIDTH = 3;
const BORDER_UNFOCUSED_WIDTH = 1;
const UNFOCUSED_LABEL_TOP_PLACEMENT = 8;
const DEFAULT_LABEL_SMALL_FONT_SIZE = 12;
const DEFAULT_LABEL_LARGE_FONT_SIZE = 16;
const DEFAULT_LABEL_SMALL_LINE_HEIGHT = 15;
const FOCUSED_LABEL_SLOT_PADDING_HORIZONTAL = 4;
const OutlinedTextInput = /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    label,
    placeholder,
    errorText,
    suportingText,
    disabled = false,
    leadingIcon,
    trailingIcon,
    leadingIconProps = {},
    trailingIconProps = {},
    leadingComponent,
    trailingComponent,
    style,
    labelStyle,
    labelSlotStyle,
    outerContainerStyle,
    innerContainerStyle,
    supportingTextStyle,
    onFocus,
    onBlur,
    onOuterContainerLayout,
    ...props
  } = _ref;
  const [labelWidth, setLabeWidth] = (0, _react.useState)(0);
  const [labelDistanceToContainerStart, setLabelDistanceToContainerStart] = (0, _react.useState)(0);
  const {
    surfaceContainer
  } = (0, _useTheme.useTheme)();
  const {
    bodyLarge,
    bodySmall
  } = (0, _useTypography.useTypography)();

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const inputRef = ref || (0, _react.useRef)(null);
  const {
    valueColor,
    selectionColor,
    placeholderColor,
    labelFocusedColor,
    trailingIconColor,
    leadingIconColor,
    labelUnfocusedColor,
    supportingTextColor,
    activeIndicatorFocusedColor,
    activeIndicatorUnfocusedColor
  } = (0, _useTextInputColors.useTextInputColors)({
    disabled,
    isError: ((errorText === null || errorText === void 0 ? void 0 : errorText.length) ?? 0) > 0
  });
  const {
    focusAnim,
    focusAnimRange,
    focusInput,
    onInputBlur,
    onInputFocus
  } = (0, _useTextInputFocusAnim.useTextInputFocus)({
    inputRef,
    onBlur,
    onFocus
  });
  const LeadingIcon = leadingIcon;
  const TrailingIcon = errorText ? _icons.ErrorIcon : trailingIcon;
  const [smallLabelFontSize, largeLabelFontSize, smallLabelHeight] = [bodySmall.fontSize ?? DEFAULT_LABEL_SMALL_FONT_SIZE, bodyLarge.fontSize ?? DEFAULT_LABEL_LARGE_FONT_SIZE, bodySmall.lineHeight ?? DEFAULT_LABEL_SMALL_LINE_HEIGHT];
  const labelFontSizeCoeff = placeholder ? 1 : smallLabelFontSize / largeLabelFontSize;
  const focusedLabelSlotWidth = labelWidth * labelFontSizeCoeff + FOCUSED_LABEL_SLOT_PADDING_HORIZONTAL * 2;
  const focusedLabelTop = -(_outlinedTextInput.OUTLINED_TEXT_INPUT_CONTAINER_PADDING_VERTICAL + smallLabelHeight / 2 + BORDER_FOCUSED_WIDTH / 2);
  const focusedLabelStart = -(labelDistanceToContainerStart - _outlinedTextInput.OUTLINED_TEXT_INPUT_CONTAINER_PADDING_HORIZONTAL - BORDER_UNFOCUSED_WIDTH);
  const focusedLabelSlotStart = _outlinedTextInput.OUTLINED_TEXT_INPUT_CONTAINER_PADDING_HORIZONTAL - FOCUSED_LABEL_SLOT_PADDING_HORIZONTAL;
  const unfocusedLabelSlotStartWithoutPlaceholder = _outlinedTextInput.OUTLINED_TEXT_INPUT_CONTAINER_PADDING_HORIZONTAL + focusedLabelSlotWidth / 2;
  const [unfocusedLabelFontSize, unfocusedLabelTop, unfocusedLabelStart, unfocusedLabelSlotWidth, unfocusedLabelSlotStart] = placeholder ? [smallLabelFontSize, focusedLabelTop, focusedLabelStart, focusedLabelSlotWidth, focusedLabelSlotStart] : [largeLabelFontSize, UNFOCUSED_LABEL_TOP_PLACEMENT, 0, 0, unfocusedLabelSlotStartWithoutPlaceholder];
  const labelSlotHeight = BORDER_FOCUSED_WIDTH * 4;
  const labelSlotTop = -(BORDER_FOCUSED_WIDTH + labelSlotHeight / 2);
  const labelAnimatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelTop, focusedLabelTop]),
    start: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelStart, focusedLabelStart]),
    color: (0, _reactNativeReanimated.interpolateColor)(focusAnim.value, focusAnimRange, [labelUnfocusedColor, labelFocusedColor]),
    fontSize: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelFontSize, smallLabelFontSize])
  }));
  const focusedLabelSlot = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    top: labelSlotTop,
    start: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelSlotStart, focusedLabelSlotStart]),
    width: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [unfocusedLabelSlotWidth, focusedLabelSlotWidth]),
    height: labelSlotHeight
  }));
  const containerAnimatedStyles = (0, _reactNativeReanimated.useAnimatedStyle)(() => ({
    borderColor: (0, _reactNativeReanimated.interpolateColor)(focusAnim.value, focusAnimRange, [activeIndicatorUnfocusedColor, activeIndicatorFocusedColor]),
    borderWidth: (0, _reactNativeReanimated.interpolate)(focusAnim.value, focusAnimRange, [BORDER_UNFOCUSED_WIDTH, BORDER_FOCUSED_WIDTH])
  }));
  const getLabelWidth = (0, _react.useCallback)(e => {
    if (!labelWidth) {
      setLabeWidth(e.nativeEvent.layout.width);
    }
  }, [labelWidth]);
  const getLabelDistanceToContainerStart = (0, _react.useCallback)(e => {
    if (!labelDistanceToContainerStart) {
      setLabelDistanceToContainerStart(e.nativeEvent.layout.x);
    }
  }, [labelDistanceToContainerStart]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: outerContainerStyle,
    onLayout: onOuterContainerLayout
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    onPress: focusInput
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_outlinedTextInput.styles.container, containerAnimatedStyles, innerContainerStyle]
  }, leadingComponent, LeadingIcon ? /*#__PURE__*/_react.default.createElement(LeadingIcon, _extends({
    color: leadingIconColor,
    style: _outlinedTextInput.styles.leadingIcon
  }, leadingIconProps)) : null, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [_outlinedTextInput.styles.labelSlot, {
      backgroundColor: surfaceContainer.backgroundLow
    }, focusedLabelSlot, labelSlotStyle]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    onLayout: getLabelDistanceToContainerStart,
    style: [_outlinedTextInput.styles.inputWithLabelContainer]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.Text, {
    onLayout: getLabelWidth,
    style: [_outlinedTextInput.styles.label, bodyLarge, labelAnimatedStyles, labelStyle]
  }, label), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    ref: inputRef,
    onBlur: onInputBlur,
    onFocus: onInputFocus,
    editable: !disabled,
    placeholder: placeholder,
    selectionColor: selectionColor,
    placeholderTextColor: placeholderColor,
    style: [_outlinedTextInput.styles.input, bodyLarge, {
      color: valueColor
    }, style]
  }, props))), trailingComponent, TrailingIcon ? /*#__PURE__*/_react.default.createElement(TrailingIcon, _extends({
    color: trailingIconColor,
    style: _outlinedTextInput.styles.trailingIcon
  }, trailingIconProps)) : null)), suportingText || errorText ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [bodySmall, _outlinedTextInput.styles.supportingText, {
      color: supportingTextColor
    }, supportingTextStyle]
  }, errorText ?? suportingText) : null);
});
exports.OutlinedTextInput = OutlinedTextInput;
//# sourceMappingURL=OutlinedTextInput.component.js.map