"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPalette = void 0;
var _materialColorUtilities = require("@material/material-color-utilities");
const HEX_REGEX = /^#(?:[A-Fa-f0-9]{3}){1,2}$/;
const RGB_REGEX = /^rgb\((\d+),\s*(\d+),\s*(\d+)\)$/;
const RGBA_REGEX = /^rgba\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+(?:\.\d+)?))?\)$/;
const getPalette = themeColros => {
  const palette = {};
  Object.entries(themeColros).forEach(_ref => {
    let [colorRole, color] = _ref;
    const colorTones = Array.from({
      length: 101
    }, (_, index) => getHexTone(color, index));
    colorTones.reduce((acc, colorTone, index) => {
      acc[`${colorRole}${index}`] = colorTone;
      return acc;
    }, palette);
  });
  return palette;
};
exports.getPalette = getPalette;
const getHexTone = (color, tone) => {
  const argbColor = _materialColorUtilities.TonalPalette.fromInt(getArgbColor(color)).tone(tone);
  return (0, _materialColorUtilities.hexFromArgb)(argbColor);
};
const getArgbColor = color => {
  if (HEX_REGEX.test(color)) {
    return (0, _materialColorUtilities.argbFromHex)(color);
  }
  const rgb = getRgb(color);
  const rgba = getRgba(color);
  if (rgb) {
    return (0, _materialColorUtilities.argbFromRgb)(rgb.r, rgb.g, rgb.b);
  }
  if (rgba) {
    return (0, _materialColorUtilities.argbFromRgba)(rgba);
  }
  throw new Error('Provided colors must be hex, rgb or rgba');
};
const getRgb = color => {
  const match = color.match(RGB_REGEX);
  return match ? {
    r: Number(match[1]),
    g: Number(match[2]),
    b: Number(match[3])
  } : null;
};
const getRgba = color => {
  const match = color.match(RGBA_REGEX);
  return match ? {
    r: Number(match[1]),
    g: Number(match[2]),
    b: Number(match[3]),
    a: Number(match[4])
  } : null;
};
//# sourceMappingURL=get-palette.js.map