function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useMemo } from 'react';
import Animated, { FadeInRight, LinearTransition, FadeOutRight } from 'react-native-reanimated';
import { TouchableOpacity } from 'react-native';
import { useTheme } from '../../../theme/useTheme.hook';
import { EditIcon } from '../../icons/edit-icon/EditIcon.component';
import { useTypography } from '../../../typography/useTypography.component';
import { getBaseFloatingButtonShape, styles } from './floating-action-button.styles';
export let FloatingActionButtonSize = /*#__PURE__*/function (FloatingActionButtonSize) {
  FloatingActionButtonSize["SMALL"] = "SMALL";
  FloatingActionButtonSize["BIG"] = "BIG";
  return FloatingActionButtonSize;
}({});
export let FloatingActionButtonType = /*#__PURE__*/function (FloatingActionButtonType) {
  FloatingActionButtonType["SURFACE"] = "SURFACE";
  FloatingActionButtonType["PRIMARY"] = "PRIMARY";
  FloatingActionButtonType["SECONDARY"] = "SECONDARY";
  FloatingActionButtonType["TERTIARY"] = "TERTIARY";
  return FloatingActionButtonType;
}({});
export const FloatingActionButton = _ref => {
  let {
    label,
    iconProps = {},
    labelStyle,
    Icon = EditIcon,
    extended = true,
    innerContainerStyle,
    size = FloatingActionButtonSize.SMALL,
    type = FloatingActionButtonType.PRIMARY,
    style,
    ...props
  } = _ref;
  const {
    labelLarge
  } = useTypography();
  const {
    shadow,
    primaryContainer,
    surfaceContainer,
    secondaryContainer,
    tertiaryContainer,
    primary
  } = useTheme();
  const colors = useMemo(() => ({
    [FloatingActionButtonType.SURFACE]: {
      backgroundColor: surfaceContainer.backgroundHigh,
      iconColor: primary.background
    },
    [FloatingActionButtonType.PRIMARY]: {
      backgroundColor: primaryContainer.background,
      iconColor: primaryContainer.text
    },
    [FloatingActionButtonType.SECONDARY]: {
      backgroundColor: secondaryContainer.background,
      iconColor: secondaryContainer.text
    },
    [FloatingActionButtonType.TERTIARY]: {
      backgroundColor: tertiaryContainer.background,
      iconColor: tertiaryContainer.text
    }
  }), []);
  const [paddingStart, paddingEnd] = label && extended ? [16, 20] : [0, 0];
  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    hitSlop: 8,
    style: [styles.container, getBaseFloatingButtonShape(size).container, style]
  }, props), /*#__PURE__*/React.createElement(Animated.View, {
    layout: LinearTransition,
    style: [styles.innerContainer, {
      backgroundColor: colors[type].backgroundColor,
      shadowColor: shadow,
      paddingStart,
      paddingEnd
    }, getBaseFloatingButtonShape(size).container, innerContainerStyle]
  }, Icon ? /*#__PURE__*/React.createElement(Icon, _extends({
    size: 24,
    color: colors[type].iconColor
  }, iconProps)) : null, label && extended ? /*#__PURE__*/React.createElement(Animated.Text, {
    layout: LinearTransition,
    exiting: FadeOutRight,
    entering: FadeInRight,
    style: [labelLarge, labelStyle]
  }, label) : null));
};
//# sourceMappingURL=FloatingActionButton.component.js.map