function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useEffect, useMemo } from 'react';
import { Pressable } from 'react-native';
import Animated, { FadeIn, FadeOut, interpolate, interpolateColor, LinearTransition, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { styles } from './button-segment.styles';
import { useTheme } from '../../../../theme/useTheme.hook';
import { convertToRGBA } from '../../../../utils/convert-to-rgba';
import { useTypography } from '../../../../typography/useTypography.component';
import { AnimatedSelectedIcon } from './animated-selected-icon/AnimatedSelectedIcon.component';
const DEFAULT_ICON_SIZE = 18;
export const ButtonSegment = /*#__PURE__*/React.memo(_ref => {
  let {
    value,
    selected,
    disabled,
    Icon,
    label,
    multiSelectionEnabled,
    withCheckmark = true,
    onSegmentPress,
    iconSize = DEFAULT_ICON_SIZE,
    labelStyle,
    iconColor,
    rippleColor,
    style,
    ...props
  } = _ref;
  const {
    labelLarge
  } = useTypography();
  const {
    surface,
    secondaryContainer
  } = useTheme();
  const fill = useSharedValue(Number(selected));
  const labelDisabledColor = useMemo(() => convertToRGBA(surface.text, 0.38), []);
  const defaultIconColor = selected ? secondaryContainer.text : iconColor ?? surface.text;
  const appliedIconColor = disabled ? labelDisabledColor : defaultIconColor;
  const iconProps = {
    size: iconSize,
    color: appliedIconColor
  };
  useEffect(() => {
    fill.value = withTiming(Number(selected));
  }, [selected]);
  const animatedLabelStyle = useAnimatedStyle(() => ({
    color: disabled ? labelDisabledColor : interpolateColor(fill.value, [0, 1], [surface.text, secondaryContainer.text])
  }), [disabled]);
  const circleAnimatedStyle = useAnimatedStyle(() => {
    return {
      opacity: fill.value,
      width: `${interpolate(fill.value, [0, 1], [0, 100])}%`
    };
  }, []);
  const handleSegmentPress = () => {
    if (multiSelectionEnabled) {
      handleMultiplyChoosing();
    } else {
      onSegmentPress([value]);
    }
  };
  const handleMultiplyChoosing = () => {
    onSegmentPress(prevValues => {
      const filteredCurrValuesDependsOnLength = prevValues.length === 1 ? prevValues : prevValues.filter(prevValue => prevValue !== value);
      return selected ? filteredCurrValuesDependsOnLength : [...prevValues, value];
    });
  };
  const renderIconConditionally = () => Icon ? /*#__PURE__*/React.createElement(Animated.View, {
    layout: LinearTransition,
    entering: FadeIn,
    exiting: FadeOut
  }, /*#__PURE__*/React.createElement(Icon, iconProps)) : null;
  return /*#__PURE__*/React.createElement(Pressable, _extends({
    style: [styles.container, style],
    disabled: disabled
  }, props, {
    onPress: handleSegmentPress
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.ripple, {
      backgroundColor: rippleColor ?? secondaryContainer.background
    }, circleAnimatedStyle]
  }), withCheckmark && selected ? /*#__PURE__*/React.createElement(Animated.View, {
    layout: LinearTransition,
    entering: FadeIn
  }, /*#__PURE__*/React.createElement(AnimatedSelectedIcon, {
    width: iconSize,
    height: iconSize,
    strokeWidth: 2,
    stroke: appliedIconColor
  })) : null, Icon && withCheckmark && label && selected ? null : renderIconConditionally(), label ? /*#__PURE__*/React.createElement(Animated.Text, {
    layout: LinearTransition,
    style: [labelLarge, animatedLabelStyle, labelStyle]
  }, label) : null);
});
//# sourceMappingURL=ButtonSegment.component.js.map