function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useMemo, useEffect } from 'react';
import Animated, { interpolateColor, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { TouchableOpacity } from 'react-native';
import { useTheme } from '../../../theme/useTheme.hook';
import { CheckSmallIcon } from '../../icons/check-small-icon/CheckSmallIcon.component';
import { DISABLED_OPACITY, ENABLED_OPACITY, getCheckboxFrameStyles, styles } from './checkbox.styles';
const DEFAULT_CHECKBOX_SIZE = 24;
const CHECKMARK_SIZE_COEFF = 0.65;
const ERROR_ANIMATION_DURATION = 300;
export const Checkbox = _ref => {
  let {
    value,
    checked,
    isError = false,
    labelEnd,
    labelStart,
    checkedIcon,
    errorColor,
    borderColor,
    checkedBorderColor,
    checkedBackgroundColor,
    style,
    checkboxStyle,
    size = DEFAULT_CHECKBOX_SIZE,
    errorAnimationDuration = ERROR_ANIMATION_DURATION,
    onCheck,
    ...props
  } = _ref;
  const errorAnim = useSharedValue(0);
  const {
    surface,
    primary,
    error
  } = useTheme();
  const {
    checkboxFrame
  } = useMemo(() => getCheckboxFrameStyles(size), [size]);
  const checkmarkSize = size * CHECKMARK_SIZE_COEFF;
  const icon = checkedIcon ?? /*#__PURE__*/React.createElement(CheckSmallIcon, {
    size: checkmarkSize
  });
  const disabledColorStyles = checked ? {
    backgroundColor: surface.text,
    borderColor: surface.text
  } : {
    backgroundColor: 'transparent',
    borderColor: surface.text
  };
  const [enabledBackgroundColor, enabledBorderColor] = checked ? [checkedBackgroundColor ?? primary.background, checkedBorderColor ?? primary.background] : ['transparent', borderColor ?? surface.textVariant];
  const checkboxColorsAnimatedStyle = useAnimatedStyle(() => ({
    backgroundColor: interpolateColor(errorAnim.value, [0, 1], [enabledBackgroundColor, checked ? errorColor ?? error.background : 'transparent']),
    borderColor: interpolateColor(errorAnim.value, [0, 1], [enabledBorderColor, errorColor ?? error.background])
  }), [enabledBackgroundColor, enabledBorderColor, errorColor, checked]);
  useEffect(() => {
    errorAnim.value = withTiming(isError ? 1 : 0, {
      duration: errorAnimationDuration
    });
  }, [isError, errorAnimationDuration]);
  const onPress = useCallback(() => {
    onCheck(value);
  }, [onCheck, value]);
  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    style: [styles.container, {
      opacity: props.disabled ? DISABLED_OPACITY : ENABLED_OPACITY
    }, style],
    onPress: onPress
  }, props), labelStart, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.checkbox, checkboxFrame, props.disabled ? disabledColorStyles : checkboxColorsAnimatedStyle, checkboxStyle]
  }, checked && icon), labelEnd);
};
//# sourceMappingURL=checkbox.component.js.map