function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useMemo, useEffect } from 'react';
import { TouchableOpacity } from 'react-native';
import Animated, { interpolate, interpolateColor, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { useTheme } from '../../../theme/useTheme.hook';
import { DISABLED_OPACITY, ENABLED_OPACITY, getRadioButtonFrameStyles, styles } from './radio-button.styles';
const DEFAULT_RADIO_SIZE = 24;
const ANIMATION_DURATION = 150;
export const RadioButton = _ref => {
  let {
    value,
    checked,
    labelEnd,
    labelStart,
    style,
    indicatorStyle,
    radioButtonStyle,
    size = DEFAULT_RADIO_SIZE,
    animationDuration = ANIMATION_DURATION,
    radioButtonColor,
    checkedRadioButtonColor,
    onCheck,
    ...props
  } = _ref;
  const anim = useSharedValue(0);
  const {
    surface,
    primary
  } = useTheme();
  const frameStyles = useMemo(() => getRadioButtonFrameStyles(size), [size]);
  const radioButtonAnimatedStyle = useAnimatedStyle(() => ({
    borderColor: interpolateColor(anim.value, [0, 1], [radioButtonColor ?? surface.textVariant, checkedRadioButtonColor ?? primary.background])
  }), [radioButtonColor, checkedRadioButtonColor]);
  const indicatorAnimatedStyle = useAnimatedStyle(() => ({
    width: interpolate(anim.value, [0, 1], [0, frameStyles.indicator.width]),
    height: interpolate(anim.value, [0, 1], [0, frameStyles.indicator.width])
  }), []);
  useEffect(() => {
    anim.value = withTiming(checked ? 1 : 0, {
      duration: animationDuration
    });
  }, [checked, animationDuration]);
  const onPress = useCallback(() => onCheck(value), [value, onCheck]);
  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    onPress: onPress,
    style: [styles.container, {
      opacity: props.disabled ? DISABLED_OPACITY : ENABLED_OPACITY
    }, style]
  }, props), labelStart, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.radioButton, frameStyles.radioButton, props.disabled ? {
      borderColor: surface.text
    } : radioButtonAnimatedStyle, radioButtonStyle]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [{
      borderRadius: frameStyles.indicator.borderRadius
    }, {
      backgroundColor: props.disabled ? surface.text : checkedRadioButtonColor ?? primary.background
    }, indicatorAnimatedStyle, indicatorStyle]
  })), labelEnd);
};
//# sourceMappingURL=RadioButton.component.js.map