function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { forwardRef, useImperativeHandle, useState } from 'react';
import Animated, { interpolate, runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { styles } from './dialog.styles';
import { useTheme } from '../../../theme/useTheme.hook';
import { ModalBackdropWrapper } from '../../modal-backdrop-wrapper/ModalBackdropWrapper.component';
const DEFAULT_ANIMATION_DURATION = 220;
export const Dialog = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    style,
    children,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const [isVisible, setIsVisible] = useState(false);
  const visibility = useSharedValue(0);
  const {
    surfaceContainer
  } = useTheme();
  useImperativeHandle(ref, () => ({
    close() {
      closeModal();
    },
    show() {
      setIsVisible(true);
      visibility.value = withTiming(1, {
        duration: animationDuration
      });
    },
    isShowed() {
      return Boolean(visibility.value);
    }
  }), [animationDuration]);
  const closeModal = () => {
    visibility.value = withTiming(0, {
      duration: animationDuration
    }, () => runOnJS(setIsVisible)(false));
  };
  const dialogAnimatedStyle = useAnimatedStyle(() => ({
    transform: [{
      scale: interpolate(visibility.value, [0, 1], [0.3, 1])
    }],
    opacity: visibility.value
  }), []);
  return /*#__PURE__*/React.createElement(ModalBackdropWrapper, {
    visibility: visibility,
    visible: isVisible,
    onRequestClose: closeModal
  }, /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: [styles.dialog, {
      backgroundColor: surfaceContainer.backgroundHigh
    }, dialogAnimatedStyle, style]
  }, props), children));
});
//# sourceMappingURL=Dialog.component.js.map