function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
import { useWindowDimensions } from 'react-native';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import { forwardRef, useImperativeHandle } from 'react';
import Animated, { interpolate, runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { useTheme } from '../../../theme/useTheme.hook';
import { styles } from './full-screen-dialog.styles';
import { ModalBackdropWrapper } from '../../modal-backdrop-wrapper/ModalBackdropWrapper.component';
export let AnimationType = /*#__PURE__*/function (AnimationType) {
  AnimationType["SLIDE"] = "SLIDE";
  AnimationType["FADE"] = "FADE";
  AnimationType["ZOOM"] = "ZOOM";
  return AnimationType;
}({});
const ANIMATION_DURATION = 330;
export const FullScreenDialog = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    children,
    animationType = AnimationType.SLIDE,
    animationDuration = ANIMATION_DURATION,
    style,
    ...props
  } = _ref;
  const [isVisible, setIsVisible] = useState(false);
  const [isClosing, setIsClosing] = useState(false);
  const insets = useSafeAreaInsets();
  const visibility = useSharedValue(0);
  const {
    surfaceContainer
  } = useTheme();
  const {
    height: windowHeight,
    width: windowWidth
  } = useWindowDimensions();
  useImperativeHandle(ref, () => ({
    show() {
      if (isClosing) {
        setIsClosing(false);
      }
      setIsVisible(true);
      visibility.value = withTiming(1, {
        duration: animationDuration
      });
    },
    close() {
      if (animationType === AnimationType.ZOOM) {
        setIsClosing(true);
      }
      visibility.value = withTiming(0, {
        duration: animationDuration
      }, () => runOnJS(setIsVisible)(false));
    },
    isShowed() {
      return Boolean(visibility.value);
    }
  }), [isClosing, animationType, animationDuration]);
  const dialogAnimatedStyle = useAnimatedStyle(() => {
    const slideAnimStyle = {
      transform: [{
        translateY: interpolate(visibility.value, [0, 1], [windowHeight, 0])
      }],
      opacity: visibility.value
    };
    switch (animationType) {
      case AnimationType.SLIDE:
        return slideAnimStyle;
      case AnimationType.FADE:
        {
          return {
            opacity: visibility.value
          };
        }
      case AnimationType.ZOOM:
        {
          return isClosing ? slideAnimStyle : {
            transform: [{
              scale: interpolate(visibility.value, [0, 1], [0.2, 1])
            }],
            opacity: visibility.value
          };
        }
      default:
        return slideAnimStyle;
    }
  }, [animationType, windowHeight, isClosing]);
  return /*#__PURE__*/React.createElement(ModalBackdropWrapper, {
    visibility: visibility,
    visible: isVisible,
    backdropStyle: styles.modalBackdropWrapper
  }, /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: [styles.container, {
      height: windowHeight,
      width: windowWidth,
      paddingTop: insets.top,
      paddingBottom: insets.bottom,
      paddingLeft: insets.left,
      paddingRight: insets.right,
      backgroundColor: surfaceContainer.backgroundHigh
    }, dialogAnimatedStyle, style]
  }, props), children));
});
//# sourceMappingURL=FullScreenDialog.component.js.map