function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useEffect } from 'react';
import { TouchableOpacity, View, StyleSheet } from 'react-native';
import Animated, { useSharedValue, withTiming, useAnimatedStyle, interpolate } from 'react-native-reanimated';
import { styles } from './nav-bar-item.styles';
import { Badge } from '../../../badge/Badge.component';
import { useTheme } from '../../../../theme/useTheme.hook';
import { DEFAULT_ICON_SIZE } from '../../../../constants/icon';
import { useTypography } from '../../../../typography/useTypography.component';
const DEFAULT_LABEL_SIZE = 12;
export const NavBarItem = _ref => {
  var _route$badge, _route$iconProps, _route$label;
  let {
    route,
    focused,
    fixedLabelVisibility,
    focusAnimDuration = 150,
    onPress,
    style,
    ...props
  } = _ref;
  const {
    surface,
    secondaryContainer
  } = useTheme();
  const {
    labelMediumProminent,
    labelMedium
  } = useTypography();
  const active = useSharedValue(Number(focused));
  useEffect(() => {
    active.value = withTiming(Number(focused), {
      duration: focusAnimDuration
    });
  }, [focused, focusAnimDuration]);
  const iconContainerAnimatedStyle = useAnimatedStyle(() => ({
    opacity: active.value,
    transform: [{
      scale: interpolate(active.value, [0, 1], [0.3, 1])
    }]
  }), []);
  const labelContainerAnimatedStyle = useAnimatedStyle(() => ({
    opacity: active.value,
    transform: [{
      translateY: interpolate(active.value, [0, 1], [labelMedium.fontSize ?? DEFAULT_LABEL_SIZE, 0])
    }]
  }), [fixedLabelVisibility]);
  const Icon = focused ? route.selectedIcon : route.icon;
  const [iconColor, labelColor, labelTypography] = focused ? [secondaryContainer.text, surface.text, labelMediumProminent] : [surface.textVariant, surface.textVariant, labelMedium];
  const onRouteButtonPress = useCallback(() => onPress(route.name), [route, onPress]);
  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    style: [styles.container, style],
    onPress: onRouteButtonPress,
    hitSlop: 12
  }, props), /*#__PURE__*/React.createElement(View, {
    style: [styles.iconWithBadge]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.iconWithBadge, {
      backgroundColor: secondaryContainer.background
    }, StyleSheet.absoluteFillObject, iconContainerAnimatedStyle]
  }), route.showBadge || (_route$badge = route.badge) !== null && _route$badge !== void 0 && _route$badge.length ? /*#__PURE__*/React.createElement(Badge, {
    size: route.badgeSize,
    value: route.badge,
    style: [styles.badge, {
      transform: [{
        translateX: (((_route$iconProps = route.iconProps) === null || _route$iconProps === void 0 ? void 0 : _route$iconProps.size) ?? DEFAULT_ICON_SIZE) - 8
      }]
    }]
  }) : null, /*#__PURE__*/React.createElement(Icon, _extends({
    size: DEFAULT_ICON_SIZE,
    color: iconColor
  }, route.iconProps ?? {}))), (_route$label = route.label) !== null && _route$label !== void 0 && _route$label.length ? /*#__PURE__*/React.createElement(Animated.Text, {
    style: [labelTypography, {
      color: labelColor
    }, fixedLabelVisibility ? {} : labelContainerAnimatedStyle]
  }, route.label) : null);
};
//# sourceMappingURL=NavBarItem.component.js.map