function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useEffect, useState } from 'react';
import { View } from 'react-native';
import Animated, { withSpring, interpolate, Extrapolation, useSharedValue, useAnimatedStyle } from 'react-native-reanimated';
import { styles } from './primary-tabs.styles';
import { useTheme } from '../../../../theme/useTheme.hook';
import { Tab as TabComponent } from '../ui/tab/Tab.component';
const BASE_INDICATOR_WIDTH = 33;
export const PrimaryTabs = _ref => {
  let {
    tabs,
    activeTab,
    badgeSize,
    scrollAnim,
    animConfig = {},
    tabStyle,
    badgeStyle,
    tabIconProps,
    tabTitleStyle,
    indicatorStyle,
    tabsContainerStyle,
    tabInnerContentStyle,
    ...props
  } = _ref;
  const [tabTextWidths, setTabTextWidths] = useState(tabs.map(() => 0));
  const {
    primary,
    outlineVariant
  } = useTheme();
  const tabWidth = `${100 / tabs.length}%`;
  const activeTabIndex = tabs.findIndex(tab => tab.routeName === activeTab);
  const calcStartIndicatorPosition = useCallback((totalTabsCount, targetTabIndex) => {
    'worklet';

    return 1 / totalTabsCount * targetTabIndex;
  }, []);
  const indicatorStartPos = useSharedValue(calcStartIndicatorPosition(tabs.length, activeTabIndex));
  useEffect(() => {
    indicatorStartPos.value = withSpring(calcStartIndicatorPosition(tabs.length, activeTabIndex), {
      duration: 300,
      dampingRatio: 1.5,
      overshootClamping: true,
      restSpeedThreshold: 0.0001,
      ...animConfig
    });
  }, [activeTabIndex]);
  const indicatorAnimatedStyle = useAnimatedStyle(() => {
    const endPosition = calcStartIndicatorPosition(tabs.length, activeTabIndex);
    const isMovingRight = indicatorStartPos.value <= endPosition;
    const prevTabIndex = isMovingRight ? activeTabIndex - 1 : activeTabIndex + 1;
    const startPosition = calcStartIndicatorPosition(tabs.length, Math.abs(prevTabIndex));
    return {
      width: interpolate(indicatorStartPos.value, [startPosition, endPosition], [tabTextWidths[prevTabIndex] ?? BASE_INDICATOR_WIDTH, tabTextWidths[activeTabIndex] ?? BASE_INDICATOR_WIDTH])
    };
  }, [activeTabIndex, tabTextWidths]);
  const indicatorContainerAnimatedStyle = useAnimatedStyle(() => {
    const maxPosition = calcStartIndicatorPosition(tabs.length, tabs.length - 1);
    return {
      start: `${interpolate(scrollAnim ? scrollAnim.value : indicatorStartPos.value, [0, maxPosition], [0, maxPosition * 100], Extrapolation.CLAMP)}%`
    };
  }, [tabs]);
  const handleTextLayout = useCallback(index => event => {
    const {
      width
    } = event.nativeEvent.layout;
    setTabTextWidths(currWidths => {
      const updatedWidths = [...currWidths];
      updatedWidths[index] = width;
      return updatedWidths;
    });
  }, []);
  const renderTab = (tab, index) => /*#__PURE__*/React.createElement(TabComponent, _extends({
    key: tab.routeName,
    onInnerContentLayout: handleTextLayout(index)
  }, tab, {
    active: tab.routeName === activeTab,
    iconProps: tabIconProps,
    badgeSize: badgeSize,
    badgeStyle: badgeStyle,
    titleStyle: tabTitleStyle,
    innerContentStyle: tabInnerContentStyle,
    style: [styles.tab, tab.style, tabStyle]
  }));
  return /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.container, {
      borderBottomColor: outlineVariant
    }]
  }, props), /*#__PURE__*/React.createElement(View, {
    style: [styles.tabs, tabsContainerStyle]
  }, tabs.map(renderTab)), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.indicatorContainer, {
      width: tabWidth
    }, indicatorContainerAnimatedStyle]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.indicator, {
      backgroundColor: primary.background,
      width: tabTextWidths[activeTabIndex]
    }, indicatorStyle, indicatorAnimatedStyle]
  })));
};
//# sourceMappingURL=PrimaryTabs.component.js.map