function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useEffect } from 'react';
import { View } from 'react-native';
import Animated, { withSpring, interpolate, Extrapolation, useSharedValue, useAnimatedStyle } from 'react-native-reanimated';
import { styles } from './secondary-tabs.styles';
import { useTheme } from '../../../../theme/useTheme.hook';
import { Tab as TabComponent, TabType } from '../ui/tab/Tab.component';
export const SecondaryTabs = _ref => {
  let {
    tabs,
    activeTab,
    badgeSize,
    scrollAnim,
    animConfig = {},
    tabStyle,
    badgeStyle,
    tabIconProps,
    tabTitleStyle,
    indicatorStyle,
    tabsContainerStyle,
    tabInnerContentStyle,
    ...props
  } = _ref;
  const {
    primary,
    outlineVariant
  } = useTheme();
  const activeTabIndex = tabs.findIndex(tab => tab.routeName === activeTab);
  const calcStartIndicatorPosition = useCallback((totalTabsCount, targetTabIndex) => {
    'worklet';

    return 1 / totalTabsCount * targetTabIndex;
  }, []);
  const indicatorStartPos = useSharedValue(calcStartIndicatorPosition(tabs.length, activeTabIndex));
  useEffect(() => {
    indicatorStartPos.value = withSpring(calcStartIndicatorPosition(tabs.length, activeTabIndex), {
      duration: 300,
      dampingRatio: 1.5,
      overshootClamping: true,
      restSpeedThreshold: 0.0001,
      ...animConfig
    });
  }, [activeTabIndex]);
  const indicatorAnimatedStyle = useAnimatedStyle(() => {
    const maxPosition = calcStartIndicatorPosition(tabs.length, tabs.length - 1);
    return {
      start: `${interpolate(scrollAnim ? scrollAnim.value : indicatorStartPos.value, [0, maxPosition], [0, maxPosition * 100], Extrapolation.CLAMP)}%`
    };
  }, [tabs]);
  const renderSecondaryTab = tab => /*#__PURE__*/React.createElement(TabComponent, _extends({
    key: tab.routeName
  }, tab, {
    type: TabType.SECONDARY,
    active: tab.routeName === activeTab,
    iconProps: tabIconProps,
    badgeSize: badgeSize,
    badgeStyle: badgeStyle,
    titleStyle: tabTitleStyle,
    style: [styles.tab, tab.style, tabStyle],
    innerContentStyle: tabInnerContentStyle
  }));
  return /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.container, {
      borderBottomColor: outlineVariant
    }]
  }, props), /*#__PURE__*/React.createElement(View, {
    style: [styles.tabs, tabsContainerStyle]
  }, tabs.map(renderSecondaryTab)), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.indicator, {
      backgroundColor: primary.background,
      width: `${100 / tabs.length}%`
    }, indicatorStyle, indicatorAnimatedStyle]
  }));
};
//# sourceMappingURL=SecondaryTabs.component.js.map