function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import { Gesture, GestureDetector } from 'react-native-gesture-handler';
import React, { useCallback, useImperativeHandle } from 'react';
import { useWindowDimensions, Platform, View } from 'react-native';
import Animated, { withTiming, interpolate, useSharedValue, useAnimatedStyle, useAnimatedProps } from 'react-native-reanimated';
import { styles } from './bottom-sheet.styles';
import { useTheme } from '../../../theme/useTheme.hook';
const AUTO_INCREASE_RANGE = 0.3;
const SWIPE_VELOCITY_THRESHOLD = 1000;
const DEFAULT_HEIGHT_COEFF = 0.4;
const DEFAULT_ANIMATION_DURATION = 300;
export const BottomSheet = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    header,
    children,
    style,
    headerStyle,
    backdropStyle,
    dragHandleStyle,
    modalHeightCoeff = DEFAULT_HEIGHT_COEFF,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const insets = useSafeAreaInsets();
  const {
    height
  } = useWindowDimensions();
  const {
    scrim,
    outline,
    surfaceContainer
  } = useTheme();
  const windowHeight = Platform.select({
    ios: height,
    android: height + insets.top,
    default: height
  });
  const modalHeight = windowHeight * modalHeightCoeff;
  const [distanceToTop, autoIncreaseTresholdTop] = [windowHeight - modalHeight, windowHeight * AUTO_INCREASE_RANGE];
  const top = useSharedValue(windowHeight);
  const context = useSharedValue({
    diffY: windowHeight,
    touchStartY: 0
  });
  const scrollTo = useCallback(destination => {
    'worklet';

    top.value = withTiming(destination, {
      duration: animationDuration
    });
  }, [animationDuration]);
  useImperativeHandle(ref, () => ({
    toggle: () => {
      scrollTo(top.value !== windowHeight ? windowHeight : distanceToTop);
    },
    expand: () => {
      scrollTo(insets.top);
    }
  }), [windowHeight]);
  const animatedStyle = useAnimatedStyle(() => ({
    top: top.value
  }), []);
  const backgroundAnimatedStyle = useAnimatedStyle(() => ({
    opacity: interpolate(top.value, [windowHeight, distanceToTop], [0, 0.32])
  }), [distanceToTop, windowHeight]);
  const backdropAnimatedProps = useAnimatedProps(() => ({
    pointerEvents: top.value !== windowHeight ? 'auto' : 'none'
  }), [windowHeight]);
  const gesture = Gesture.Pan().onStart(e => {
    context.value.diffY = top.value - e.absoluteY;
    context.value.touchStartY = e.absoluteY;
  }).onUpdate(e => {
    top.value = context.value.diffY + e.absoluteY;
  }).onEnd(e => {
    const swipeDown = e.velocityY > SWIPE_VELOCITY_THRESHOLD && e.absoluteY > context.value.touchStartY;
    const swipeUp = e.velocityY < -SWIPE_VELOCITY_THRESHOLD;
    if (swipeDown || top.value > distanceToTop) {
      scrollTo(windowHeight);
    } else if (swipeUp || top.value < autoIncreaseTresholdTop) {
      scrollTo(insets.top);
    }
  });
  const closeModal = useCallback(() => {
    scrollTo(windowHeight);
  }, [windowHeight]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Animated.View, {
    onTouchStart: closeModal,
    animatedProps: backdropAnimatedProps,
    style: [styles.backdrop, {
      backgroundColor: scrim
    }, backgroundAnimatedStyle, backdropStyle]
  }), /*#__PURE__*/React.createElement(GestureDetector, {
    gesture: gesture
  }, /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: [styles.bottomSheet, {
      backgroundColor: surfaceContainer.backgroundLow
    }, animatedStyle, style]
  }, props), /*#__PURE__*/React.createElement(View, {
    style: [styles.header, headerStyle]
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.dragHandle, {
      backgroundColor: outline
    }, dragHandleStyle]
  }), header), children)));
});
//# sourceMappingURL=BottomSheet.component.js.map