function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import { Gesture, GestureDetector } from 'react-native-gesture-handler';
import React, { useCallback, useImperativeHandle } from 'react';
import { useWindowDimensions } from 'react-native';
import Animated, { withTiming, interpolate, useSharedValue, useAnimatedStyle, useAnimatedProps } from 'react-native-reanimated';
import { styles } from './side-sheet.styles';
import { useTheme } from '../../../theme/useTheme.hook';
const DEFAULT_ANIMATION_DURATION = 300;
const DEFAULT_WIDTH_COEFF = 0.85;
export const SideSheet = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    children,
    style,
    backdropStyle,
    stickySide = 'right',
    modalWidthCoeff = DEFAULT_WIDTH_COEFF,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    ...props
  } = _ref;
  const {
    scrim,
    surfaceContainer
  } = useTheme();
  const {
    width: windowWidth
  } = useWindowDimensions();
  const modalWidth = windowWidth * modalWidthCoeff;
  const onOpenDistanceToEdge = windowWidth - modalWidth;
  const edge = useSharedValue(windowWidth);
  const diffX = useSharedValue(modalWidth);
  const scrollTo = useCallback(destination => {
    'worklet';

    edge.value = withTiming(destination, {
      duration: animationDuration
    });
  }, [animationDuration]);
  useImperativeHandle(ref, () => ({
    toggle: () => {
      scrollTo(edge.value !== windowWidth ? windowWidth : onOpenDistanceToEdge);
    }
  }), [onOpenDistanceToEdge, windowWidth]);
  const leftSideSheetAnimatedStyle = useAnimatedStyle(() => ({
    right: edge.value
  }), []);
  const rightSideSheetAtyle = useAnimatedStyle(() => ({
    left: edge.value
  }), []);
  const backgroundAnimatedStyle = useAnimatedStyle(() => ({
    opacity: interpolate(edge.value, [windowWidth, onOpenDistanceToEdge], [0, 0.32])
  }), [onOpenDistanceToEdge, windowWidth]);
  const backdropAnimatedProps = useAnimatedProps(() => ({
    pointerEvents: edge.value !== windowWidth ? 'auto' : 'none'
  }), [windowWidth]);
  const gesture = Gesture.Pan().onStart(e => {
    diffX.value = stickySide === 'right' ? e.absoluteX - edge.value : windowWidth - e.absoluteX - edge.value;
  }).onUpdate(e => {
    if (stickySide === 'right') {
      edge.value = e.absoluteX - diffX.value;
    }
    if (stickySide === 'left') {
      edge.value = windowWidth - e.absoluteX - diffX.value;
    }
  }).onEnd(() => {
    const closeTreshold = onOpenDistanceToEdge + windowWidth * 0.2;
    if (edge.value > closeTreshold) {
      scrollTo(windowWidth);
    } else {
      scrollTo(onOpenDistanceToEdge);
    }
  });
  const closeModal = useCallback(() => {
    scrollTo(windowWidth);
  }, [windowWidth]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Animated.View, {
    onTouchStart: closeModal,
    animatedProps: backdropAnimatedProps,
    style: [styles.backdrop, {
      backgroundColor: scrim
    }, backgroundAnimatedStyle, backdropStyle]
  }), /*#__PURE__*/React.createElement(GestureDetector, {
    gesture: gesture
  }, /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: [styles.sideSheet, {
      backgroundColor: surfaceContainer.backgroundLow
    }, stickySide === 'right' ? [styles.rightSideSheet, rightSideSheetAtyle] : [styles.leftSideSheet, leftSideSheetAnimatedStyle], style]
  }, props), children)));
});
//# sourceMappingURL=SideSheet.component.js.map