function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from 'react';
import { View } from 'react-native';
import { GestureDetector } from 'react-native-gesture-handler';
import { styles } from './slider.styles';
import { useSlider } from './useSlider.hook';
import { useSliderColors } from '../use-slider-colors.hook';
import { useSliderTrackPoints } from './useSliderTrackPoints.hook';
import { SliderTrack } from '../ui/slider-track/SliderTrack.component';
import { SliderIndicator } from '../ui/slider-indicator/SliderIndicator.component';
import { SliderTrackPoint } from '../ui/slider-track-point/SliderTrackPoint.component';
export const Slider = _ref => {
  let {
    max,
    min,
    step,
    value = 0,
    damping = 20,
    disabled = false,
    centered = false,
    thumbStyle,
    valueStyle,
    indicatorStyle,
    trackPointStyle,
    trackPointsStyle,
    filledTrackStyle,
    remainingTrackStyle,
    valueHeight,
    thumbWidthActive,
    thumbWidthInactive,
    onChangeValue,
    onLayout,
    style,
    ...props
  } = _ref;
  const {
    filledTrackColor,
    remainingTrackColor
  } = useSliderColors(disabled, centered);
  const trackPoints = useSliderTrackPoints({
    max,
    min,
    step,
    centered
  });
  const {
    gesture,
    sliding,
    selectedValue,
    animValueProps,
    filledTrackAnimatedStyle,
    remainingTrackAnimatedStyle,
    slideToTrackPoint,
    setUpSliderLayout
  } = useSlider({
    max,
    min,
    step,
    damping
  }, value, onChangeValue);
  const trackPointsJustifyContent = trackPoints.length > 1 ? 'space-between' : 'flex-end';
  const handleLayoutChange = e => {
    setUpSliderLayout(e.nativeEvent.layout.width);
    if (onLayout) {
      onLayout(e);
    }
  };
  const renderTrackPoint = pointValue => /*#__PURE__*/React.createElement(SliderTrackPoint, {
    key: pointValue,
    value: pointValue,
    selectedValue: selectedValue,
    disabled: disabled,
    onPress: slideToTrackPoint,
    disableColorChange: centered,
    style: trackPointStyle
  });
  return /*#__PURE__*/React.createElement(GestureDetector, {
    gesture: gesture.enabled(!disabled)
  }, /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.container, style],
    onLayout: handleLayoutChange
  }, props), /*#__PURE__*/React.createElement(SliderTrack, {
    style: [{
      backgroundColor: filledTrackColor
    }, styles.filledTrack, filledTrackAnimatedStyle, filledTrackStyle]
  }), /*#__PURE__*/React.createElement(SliderIndicator, {
    sliding: sliding,
    disabled: disabled,
    animValueProps: animValueProps,
    style: [styles.thumb, indicatorStyle],
    thumbStyle: thumbStyle,
    valueStyle: valueStyle,
    valueHeight: valueHeight,
    thumbWidthActive: thumbWidthActive,
    thumbWidthInactive: thumbWidthInactive
  }), /*#__PURE__*/React.createElement(SliderTrack, {
    style: [{
      backgroundColor: remainingTrackColor
    }, styles.remainingTrack, remainingTrackAnimatedStyle, remainingTrackStyle]
  }), /*#__PURE__*/React.createElement(View, {
    style: [styles.trackPoints, {
      justifyContent: trackPointsJustifyContent
    }, trackPointsStyle]
  }, trackPoints.map(renderTrackPoint))));
};
//# sourceMappingURL=Slider.component.js.map