import React, { useMemo } from 'react';
import Animated, { interpolate, useAnimatedStyle } from 'react-native-reanimated';
import { View, TextInput } from 'react-native';
import { styles } from './slider-indicator.styles';
import { useTheme } from '../../../../theme/useTheme.hook';
import { convertToRGBA } from '../../../../utils/convert-to-rgba';
import { useTypography } from '../../../../typography/useTypography.component';
Animated.addWhitelistedNativeProps({
  text: true
});
const AnimatedTextInput = Animated.createAnimatedComponent(TextInput);
const THUMB_VALUE_GAP = 4;
export const SliderIndicator = _ref => {
  let {
    sliding,
    disabled,
    animValueProps,
    thumbStyle,
    valueStyle,
    valueHeight = 44,
    thumbWidthActive = 2,
    thumbWidthInactive = 4,
    ...props
  } = _ref;
  const {
    labelLarge
  } = useTypography();
  const {
    surface,
    primary
  } = useTheme();
  const disabledColor = useMemo(() => convertToRGBA(surface.text, 0.38), [surface.text]);
  const valueAnimatedStyle = useAnimatedStyle(() => {
    const topActive = -valueHeight - THUMB_VALUE_GAP;
    return {
      opacity: sliding.value,
      transform: [{
        scale: sliding.value
      }],
      top: interpolate(sliding.value, [0, 1], [topActive / 2, -valueHeight - THUMB_VALUE_GAP])
    };
  }, [valueHeight]);
  const thumbAnimatedStyle = useAnimatedStyle(() => ({
    width: interpolate(sliding.value, [0, 1], [thumbWidthInactive, thumbWidthActive])
  }), [thumbWidthActive, thumbWidthInactive]);
  return /*#__PURE__*/React.createElement(View, props, /*#__PURE__*/React.createElement(AnimatedTextInput, {
    editable: false,
    animatedProps: animValueProps,
    style: [labelLarge, styles.value, {
      backgroundColor: surface.backgroundInverse,
      height: valueHeight
    }, valueAnimatedStyle, {
      color: surface.textInverse
    }, valueStyle]
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.thumb, {
      backgroundColor: disabled ? disabledColor : primary.background
    }, thumbAnimatedStyle, thumbStyle]
  }));
};
//# sourceMappingURL=SliderIndicator.component.js.map