function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useCallback, useEffect, useImperativeHandle, useRef } from 'react';
import Animated, { interpolate, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { View, Text, TouchableOpacity } from 'react-native';
import { styles } from './snackbar.styles';
import { useTheme } from '../../theme/useTheme.hook';
import { CloseIcon } from '../icons/close-icon/CloseIcon.component';
const DISAPPEAR_COEFF = 0.5;
const DEFAULT_OFFSET = 64;
const DEFAULT_ICON_SIZE = 20;
const DEFAULT_SHOW_DURATION = 2000;
const DEFAULT_ANIMATION_DURATION = 500;
export const Snackbar = /*#__PURE__*/React.forwardRef((_ref, ref) => {
  let {
    content,
    action = '',
    showCloseIcon = false,
    offset = DEFAULT_OFFSET,
    duration = DEFAULT_SHOW_DURATION,
    style,
    actionStyle,
    contentStyle,
    closeIconColor,
    closeIconSize = DEFAULT_ICON_SIZE,
    animationDuration = DEFAULT_ANIMATION_DURATION,
    onActionPress,
    ...props
  } = _ref;
  const visibility = useSharedValue(0);
  const {
    primary,
    surface
  } = useTheme();
  const timeout = useRef(null);
  const hideSnackbar = useCallback(() => {
    visibility.value = withTiming(0, {
      duration: animationDuration
    });
    if (timeout.current) {
      clearTimeout(timeout.current);
    }
  }, [animationDuration, timeout.current]);
  useEffect(() => hideSnackbar, []);
  useImperativeHandle(ref, () => ({
    show() {
      visibility.value = withTiming(1, {
        duration: animationDuration
      });
      timeout.current = setTimeout(() => {
        hideSnackbar();
      }, duration);
    },
    dismiss() {
      hideSnackbar();
      timeout.current = null;
    }
  }), [hideSnackbar, animationDuration, duration]);
  const snackbarAnimatedStyle = useAnimatedStyle(() => ({
    opacity: visibility.value,
    bottom: interpolate(visibility.value, [0, 1], [offset * DISAPPEAR_COEFF, offset])
  }), [offset]);
  return /*#__PURE__*/React.createElement(Animated.View, _extends({
    style: [styles.container, {
      backgroundColor: surface.backgroundInverse
    }, snackbarAnimatedStyle, style]
  }, props), /*#__PURE__*/React.createElement(Text, {
    style: [{
      color: surface.textInverse
    }, styles.supportingText, contentStyle]
  }, content), /*#__PURE__*/React.createElement(View, {
    style: styles.actions
  }, action.length > 0 && /*#__PURE__*/React.createElement(TouchableOpacity, {
    hitSlop: 16,
    onPress: onActionPress
  }, /*#__PURE__*/React.createElement(Text, {
    style: [{
      color: primary.backgroundInverse
    }, styles.mainAction, actionStyle]
  }, action)), showCloseIcon && /*#__PURE__*/React.createElement(TouchableOpacity, {
    hitSlop: 16,
    onPress: hideSnackbar
  }, /*#__PURE__*/React.createElement(CloseIcon, {
    size: closeIconSize,
    color: closeIconColor ?? surface.text
  }))));
});
//# sourceMappingURL=Snackbar.component.js.map