function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { forwardRef, useRef } from 'react';
import Animated, { useAnimatedStyle, interpolateColor, interpolate } from 'react-native-reanimated';
import { Text, View, TextInput, TouchableWithoutFeedback } from 'react-native';
import { ErrorIcon } from '../../icons';
import { styles } from './filled-text-input.styles';
import { useTextInputColors } from '../use-text-input-colors.hook';
import { useTextInputFocus } from '../use-text-input-focus-anim.hook';
import { useTypography } from '../../../typography/useTypography.component';
const UNFOCUSED_LABEL_TOP_PLACEMENT = 8;
const DEFAULT_LABEL_SMALL_FONT_SIZE = 12;
const DEFAULT_LABEL_LARGE_FONT_SIZE = 16;
const ACTIVE_INDICATOR_FOCUSED_HEIGHT = 3;
const ACTIVE_INDICATOR_UNFOCUSED_HEIGHT = 1;
export const FilledTextInput = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    label,
    placeholder,
    errorText,
    suportingText,
    disabled = false,
    leadingIcon,
    trailingIcon,
    leadingIconProps = {},
    trailingIconProps = {},
    leadingComponent,
    trailingComponent,
    style,
    labelStyle,
    outerContainerStyle,
    innerContainerStyle,
    supportingTextStyle,
    activeIndicatorStyle,
    onFocus,
    onBlur,
    onOuterContainerLayout,
    ...props
  } = _ref;
  const {
    bodyLarge,
    bodySmall
  } = useTypography();
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const inputRef = ref || useRef(null);
  const {
    valueColor,
    containerColor,
    selectionColor,
    placeholderColor,
    labelFocusedColor,
    trailingIconColor,
    leadingIconColor,
    labelUnfocusedColor,
    supportingTextColor,
    activeIndicatorFocusedColor,
    activeIndicatorUnfocusedColor
  } = useTextInputColors({
    disabled,
    isError: ((errorText === null || errorText === void 0 ? void 0 : errorText.length) ?? 0) > 0
  });
  const {
    focusAnim,
    focusAnimRange,
    focusInput,
    onInputBlur,
    onInputFocus
  } = useTextInputFocus({
    inputRef,
    onBlur,
    onFocus
  });
  const LeadingIcon = leadingIcon;
  const TrailingIcon = errorText ? ErrorIcon : trailingIcon;
  const [smallLabelFontSize, largeLabelFontSize] = [bodySmall.fontSize ?? DEFAULT_LABEL_SMALL_FONT_SIZE, bodyLarge.fontSize ?? DEFAULT_LABEL_LARGE_FONT_SIZE];
  const [unfocusedLabelFontSize, unfocusedLabelTopPlacement] = placeholder ? [smallLabelFontSize, 0] : [largeLabelFontSize, UNFOCUSED_LABEL_TOP_PLACEMENT];
  const labelAnimatedStyles = useAnimatedStyle(() => ({
    top: interpolate(focusAnim.value, focusAnimRange, [unfocusedLabelTopPlacement, 0]),
    color: interpolateColor(focusAnim.value, focusAnimRange, [labelUnfocusedColor, labelFocusedColor]),
    fontSize: interpolate(focusAnim.value, focusAnimRange, [unfocusedLabelFontSize, smallLabelFontSize])
  }), [labelUnfocusedColor, labelFocusedColor, unfocusedLabelTopPlacement, unfocusedLabelFontSize, smallLabelFontSize]);
  const activeIndicatorAnimatedStyles = useAnimatedStyle(() => ({
    backgroundColor: interpolateColor(focusAnim.value, focusAnimRange, [activeIndicatorUnfocusedColor, activeIndicatorFocusedColor]),
    height: interpolate(focusAnim.value, focusAnimRange, [ACTIVE_INDICATOR_UNFOCUSED_HEIGHT, ACTIVE_INDICATOR_FOCUSED_HEIGHT])
  }), [activeIndicatorUnfocusedColor, activeIndicatorFocusedColor]);
  return /*#__PURE__*/React.createElement(View, {
    style: outerContainerStyle,
    onLayout: onOuterContainerLayout
  }, /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    onPress: focusInput
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.container, {
      backgroundColor: containerColor
    }, innerContainerStyle]
  }, leadingComponent, LeadingIcon ? /*#__PURE__*/React.createElement(LeadingIcon, _extends({
    color: leadingIconColor,
    style: styles.leadingIcon
  }, leadingIconProps)) : null, /*#__PURE__*/React.createElement(View, {
    style: [styles.inputWithLabelContainer]
  }, /*#__PURE__*/React.createElement(Animated.Text, {
    style: [styles.label, bodyLarge, labelAnimatedStyles, labelStyle]
  }, label), /*#__PURE__*/React.createElement(TextInput, _extends({
    ref: inputRef,
    onBlur: onInputBlur,
    onFocus: onInputFocus,
    editable: !disabled,
    placeholder: placeholder,
    selectionColor: selectionColor,
    placeholderTextColor: placeholderColor,
    style: [styles.input, bodyLarge, {
      color: valueColor
    }, style]
  }, props))), TrailingIcon ? /*#__PURE__*/React.createElement(TrailingIcon, _extends({
    color: trailingIconColor,
    style: styles.trailingIcon
  }, trailingIconProps)) : null, trailingComponent, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.activeIndicator, activeIndicatorAnimatedStyles, activeIndicatorStyle]
  }))), suportingText || errorText ? /*#__PURE__*/React.createElement(Text, {
    style: [bodySmall, styles.supportingText, {
      color: supportingTextColor
    }, supportingTextStyle]
  }, errorText ?? suportingText) : null);
});
//# sourceMappingURL=FilledTextInput.component.js.map